OC.L10N.register(
    "spreed",
    {
    "a conversation" : "una conversación",
    "(Duration %s)" : "(Duración %s)",
    "You attended a call with {user1}" : "Has participado en una llamada con {user1}",
    "_%n guest_::_%n guests_" : ["%n invitado","%n invitados","%n invitados"],
    "You attended a call with {user1} and {user2}" : "Has participado en una llamada con {user1} y {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Has participado en una llamada con {user1}, {user2} y {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Has participado en una llamada con {user1}, {user2}, {user3} y {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Has participado en una llamada con {user1}, {user2}, {user3}, {user4} y {user5}",
    "_%n other_::_%n others_" : ["%n otro","%n otros","%n otros"],
    "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Fuiste invitado a una <strong>conversación</strong> o tuviste una <strong>llamada</strong>",
    "Other activities" : "Otras actividades",
    "Talk" : "Talk",
    "Guest" : "Invitado",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "## ¡Le damos la bienvenida a Nextcloud Talk!\nEn esta convesación se le informará sobre las nuevas características disponibles en Nextcloud Talk.",
    "## New in Talk %s" : "## Nuevo en Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : " Se puede usar Microsoft Edge y Safari para participar en llamadas de audio y de vídeo",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "* Las conversaciones individuales ahora son persistentes y ya no se pueden convertirse en conversaciones de grupo por accidente. Además, cuando uno de los participantes abandone la conversación, esta ya no se borrará automáticamente. Solo si ambos participantes se van, la conversación se borra del servidor",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Ahora puedes enviar una notificación a todos los participantes escribiendo \"@all\" en el chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Con la tecla \"flecha hacia arriba\" puedes volver a enviar el último mensaje",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Ahora, Talk dispone de comandos. Envia \"/help\" como un mensaje de chat para comprobar si tu administrador ha configurado alguno",
    "- With projects you can create quick links between conversations, files and other items" : "- Con los proyectos, puedes crear enlaces rápidos entre conversaciones, archivos y otros objetos",
    "- You can now mention guests in the chat" : "- Ahora puedes mencionar a los invitados en la conversación",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Ahora, las conversaciones pueden tener una sala de espera. Esto permite a los moderadores unirse al chat y llamar inmediatamente para preparar la reunión, mientras que los usuarios y los invitados tienen que esperar",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Ahora puedes responder directamente a los mensajes, dando a los usuarios más contexto sobre el tema de tu mensaje",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- La búsqueda por conversaciones y participantes también filtrará tus conversaciones existentes, haciendo mucho más fácil encontrar conversaciones previas",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Puedes añadir grupos personalizados de usuarios a las conversaciones cuando la app de Círculos está instalada",
    "- Check out the new grid and call view" : "- Una nueva cuadrícula y vista de llamadas.",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Ya puedes subir y arrastrar archivos desde tu dispositivo al chat.",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Los archivos compartidos se abrirán ahora dentro del chat con el visor que corresponda.",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Ahora puedes buscar chats y mensajes en la búsqueda unificada de la barra superior.",
    "- Spice up your messages with emojis from the emoji picker" : "- Dales sabor a tus mensajes con emojis desde el selector.",
    "- You can now change your camera and microphone while being in a call" : "- Ahora puedes cambiar la cámara y el micrófono mientras estás en una llamada.",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- De un cierto contexto a la conversación con una descripción y ábrela para que los usuarios registrados puedan encontrarla y unirse ellos mismos",
    "- See a read status and send failed messages again" : "- Ver un estado de lectura y enviar nuevamente los mensajes fallidos ",
    "- Raise your hand in a call with the R key" : "- Levante la mano en una llamada con la tecla R",
    "- Join the same conversation and call from multiple devices" : "- Únase a la misma conversación y llamada desde varios dispositivos",
    "- Send voice messages, share your location or contact details" : "- Envíe mensajes de voz, comparta su ubicación o sus datos de contacto",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Añada grupos a una conversación y los nuevos miembros del grupo se añadirán automáticamente como participantes",
    "- A preview of your audio and video is shown before joining a call" : "- Una previsualización de su audio y vídeo se mostrará antes de unirse a la llamada",
    "- You can now blur your background in the newly designed call view" : "- Ahora puede desenfocar su fondo usando el nuevo diseño de la vista de llamada",
    "- Moderators can now assign general and individual permissions to participants" : "- Ahora los moderadores pueden asignar permisos generales e individuales a los participantes",
    "- You can now react to chat messages" : "- Ahora puede reaccionar a los mensajes del chat",
    "- In the sidebar you can now find an overview of the latest shared items" : "- En la barra lateral ahora podrá encontrar una vista general de los últimos artículos compartidos",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Utilice una encuesta para recolectar las opiniones o para acordar una fecha",
    "- Configure an expiration time for chat messages" : "- Configure un tiempo de expiración para los mensajes de chat",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Inicie llamadas sin notificar a otros en conversaciones numerosas. Puede enviar notificaciones de llamada individuales una vez que la llamada ha iniciado.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Enviar mensajes de chat sin notificar a los recipientes en caso de que no sea urgente",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Los emojis pueden ser autocompletados escribiendo \":\"",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Enlace varios ítems utilizando el nuevo selector inteligente escribiendo una \"/\"",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Ahora, los moderadores pueden crear salas de grupos (requiere el motor de alto rendimiento)",
    "- Calls can now be recorded (requires the High-performance backend)" : "- Las llamadas ahora pueden ser grabadas (requiere el motor de alto rendimiento)",
    "- Conversations can now have an avatar or emoji as icon" : "- Ahora, las conversaciones pueden tener como icono un avatar o emoji",
    "- Virtual backgrounds are now available in addition to the blurred background in video calls" : "- Están disponibles ahora los fondos virtuales, además de los fondos desenfocados en las llamadas de video",
    "- Reactions are now available during calls" : "- Las reacciones están ahora disponibles durante las llamadas",
    "- Typing indicators show which users are currently typing a message" : "- Los indicadores de escritura muestran que usuarios están escribiendo un mensaje",
    "- Groups can now be mentioned in chats" : "- Los grupos ahora pueden ser mencionados en los chats",
    "- Call recordings are automatically transcribed if a transcription provider app is registered" : "- Las grabaciones de llamadas serán automáticamente transcritas si una app que provea transcripciones está registrada",
    "- Chat messages can be translated if a translation provider app is registered" : "- Los mensajes de chat pueden ser traducidos si una app que provea transcripciones está registrada",
    "- **Markdown** can now be used in _chat_ messages" : "- Ahora se puede usar **Markdown** en mensajes de _chat_",
    "- Webhooks are now available to implement bots. See the documentation for more information https://nextcloud-talk.readthedocs.io/en/latest/bot-list/" : "- Ya se encuentran disponibles Webhooks para implementar bots. Vea la documentación para más información https://nextcloud-talk.readthedocs.io/en/latest/bot-list/",
    "- Set a reminder on a chat message to be notified later again" : "- Establecer un recordatorio en un mensaje de chat para que sea notificado nuevamente más tarde",
    "- Use the **Note to self** conversation to take notes and share information between your devices" : "- Utiliza la conversación **Nota personal** para tomar notas y compartir información entre tus dispositivos",
    "- Captions allow to send a message with a file at the same time" : "- Las leyendas permiten enviar un mensaje con un archivo al mismo tiempo",
    "- Video of the speaker is now visible while sharing the screen and call reactions are animated" : "- El video del orador ahora es visible mientras se comparte la pantalla y las reacciones de la llamada están animadas",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Los mensajes pueden ser editados ahora por los administradores y moderadores con sesión iniciada por 6 horas",
    "- Unsent message drafts are now saved in your browser" : "- Los borradores de mensajes no enviados se guardan ahora en su navegador",
    "- Text chatting can now be done in a federated way with other Talk servers" : "- Se puede chatear por texto de forma federada con otros servidores de Talk",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Los moderadores ahora pueden bloquear tanto a cuentas como a invitados de volver a unirse a una conversación",
    "- Upcoming calls from linked calendar events and out-of-office replacements are now shown in conversations" : "- Las llamadas entrantes de eventos de calendario enlazados y sustituciones de fuera de la oficina ahora se muestran en las conversaciones",
    "- Calls can now be done in a federated way with other Talk servers (requires the High-performance backend)" : "- Las llamadas ahora se pueden hacer de forma federada con otros servidores de Talk (requiere el motor de alto rendimiento)",
    "- Introducing the Nextcloud Talk desktop client for Windows, macOS and Linux: %s" : "- Presentando el cliente de escritorio Nextcloud Talk para Windows, macOS y Linux: %s",
    "- Summarize call recordings and unread messages in chats with the Nextcloud Assistant" : "- Resuma grabaciones de llamadas y mensajes de chat no leídos con el Asistente Nextcloud",
    "- Improved meetings with recognizing guests invited via their email address, import of participant lists, drafts for polls and downloading call participant lists" : "- Reuniones mejoradas con reconocimiento de invitados a través de su dirección de correo, importación de listas de participantes, borradores para encuestas y la posibilidad de descargar la lista de participantes de las llamadas",
    "- Archive conversations to stay focused" : "- Archive conversaciones para mantenerse enfocado",
    "- Schedule a meeting into your calendar from within a conversation" : "- Agendar reuniones dentro de su calendario directamente desde una conversación",
    "- Search for messages of the current conversation directly in the right sidebar" : "- Buscar mensajes de la conversación actual directamente en la barra lateral derecha",
    "- See more conversations on a first glance with the new compact list (enable in the Talk settings)" : "- Vea más conversaciones de un vistazo con la nueva lista compacta (habilitar en los ajustes de Talk)",
    "- Meeting conversations now sync the title and description from the calendar and are hidden with a search filter until they are close to the start" : "- Las conversaciones de las Reuniones ahora sincronizan el título y la descripción desde el calendario y están ocultas con un filtro de búsqueda hasta que están por comenzar",
    "- Mark conversations as sensitive in the notification settings, to hide the message content from the conversation list and notifications" : "- Maque las conversaciones como sensibles en los ajustes de notificaciones, de manera de esconder el contenido del mensaje de la lista de conversaciones y las notificaciones",
    "- To receive push notifications during \"Do not disturb\", mark conversations as important" : "- Para recibir notificaciones push durante el estado \"No molestar\", marque las conversaciones como importantes",
    "- Add other participants to a one-to-one call to create a new group call on the fly" : "- Añada a otros participantes en una llamada uno a uno para crear una nueva llamada grupal al vuelo",
    "- Use threads to keep your chat and discussions organized" : "- Use hilos para mantener sus chats y discusiones organizadas",
    "- Live transcriptions now available during the call (requires the live-transcription ExApp and the High-performance backend)" : "- Las transcripciones en vivo están ahora disponibles durante la llamada (requiere la ExApp de transcripción en vivo y el backend de alto rendimiento)",
    "- Moderators can now pin messages so they are kept at the top" : "- Los moderadores ahora pueden fijar mensajes para que se mantengan en la parte superior",
    "- Schedule a message to send it at a later time" : "- Programa un mensaje para enviarlo después",
    "_All %n participant_::_All %n participants_" : ["%n participante","Todos los %n participantes","Todos los %n participantes"],
    "Talk updates ✅" : "Actualizaciones de Talk ✅",
    "Reaction deleted by author" : "Reacción borrada por el autor",
    "{actor} created the conversation" : "{actor} creó la conversación",
    "You created the conversation" : "Has creado la conversación",
    "System created the conversation" : "El sistema creó la conversación",
    "An administrator created the conversation" : "Un administrador ha creado la conversación",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} ha renombrado la conversación de \"%1$s\" a \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Has renombrado la conversación de \"%1$s\" a \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Un administrador ha cambiado el nombre de la conversación «%1$s» a «%2$s»",
    "{actor} set the description" : "{actor} estableció la descripción",
    "You set the description" : "Usted estableció la descripción",
    "An administrator set the description" : "Un administrador estableció la descripción",
    "{actor} removed the description" : "{actor} ha eliminado la descripción",
    "You removed the description" : "Has eliminado la descripción",
    "An administrator removed the description" : "Un administrador ha eliminado la descripción",
    "You started a silent call" : "Ud. inició una llamada silenciosa",
    "Outgoing silent call" : "Llamada saliente silenciosa",
    "{actor} started a silent call" : "{actor} inició una llamada silenciosa",
    "Incoming silent call" : "Llamada entrante silenciosa",
    "You started a call" : "Has iniciado una llamada",
    "Outgoing call" : "Llamada saliente",
    "{actor} started a call" : "{actor} ha iniciado una llamada",
    "Incoming call" : "Llamada entrante",
    "{actor} joined the call" : "{actor} se ha unido a la llamada",
    "You joined the call" : "Te has unido a la llamada",
    "{actor} left the call" : "{actor} ha abandonado la llamada",
    "You left the call" : "Has abandonado la llamada",
    "{actor} unlocked the conversation" : "{actor} ha desbloqueado la conversación",
    "You unlocked the conversation" : "Has desbloqueado la conversación",
    "An administrator unlocked the conversation" : "Un administrador ha desbloqueado la conversación",
    "{actor} locked the conversation" : "{actor} ha bloqueado la conversación",
    "You locked the conversation" : "Has bloqueado la conversación",
    "An administrator locked the conversation" : "Un administrador ha bloqueado la conversación",
    "{actor} limited the conversation to the current participants" : "{actor} limitó la conversación a los participantes actuales",
    "You limited the conversation to the current participants" : "Has limitado la conversación a los participantes actuales",
    "An administrator limited the conversation to the current participants" : "Un administrador limitó la conversación a los participantes actuales",
    "{actor} opened the conversation to registered users" : "{actor} abrió la conversación a los usuarios registrados",
    "You opened the conversation to registered users" : "Has abierto la conversación a los usuarios registrados",
    "An administrator opened the conversation to registered users" : "Un administrador abrió la conversación a los usuarios registrados",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} abrió la conversación a usuarios registrados y para aquellos usuarios creados con la aplicación de Invitados",
    "You opened the conversation to registered users and users created with the Guests app" : "Ha abierto la conversación a usuarios registrados y para aquellos usuarios creados con la aplicación de Invitados",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Un administrador ha abierto la conversación a usuarios registrados y para aquellos usuarios creados con la aplicación de Invitados",
    "The conversation is now open to everyone" : "La conversación ahora está abierta para todo el mundo",
    "{actor} opened the conversation to everyone" : "{actor} ha abierto la conversación para todos",
    "You opened the conversation to everyone" : "Has abierto la conversación para todo el mundo",
    "{actor} restricted the conversation to moderators" : "{actor} restringió la conversación únicamente a los moderadores",
    "You restricted the conversation to moderators" : "Restringiste la conversación únicamente a los moderadores",
    "{actor} started breakout rooms" : "{actor} inició las salas de grupos",
    "You started breakout rooms" : "Ud. inició las salas de grupos",
    "{actor} stopped breakout rooms" : "{actor} detuvo las salas de grupos",
    "You stopped breakout rooms" : "Ud. detuvo las salas de grupos",
    "{actor} allowed guests" : "{actor} ha permitido invitados",
    "You allowed guests" : "Has permitido invitados",
    "An administrator allowed guests" : "Un administrador ha permitido invitados",
    "{actor} disallowed guests" : "{actor} ha prohibido invitados",
    "You disallowed guests" : "Has prohibido invitados",
    "An administrator disallowed guests" : "Un administrador ha prohibido invitados",
    "{actor} set a password" : "{actor} ha establecido una contraseña",
    "You set a password" : "Has establecido una contraseña",
    "An administrator set a password" : "Un administrador ha establecido una contraseña",
    "{actor} removed the password" : "{actor} ha eliminado la contraseña",
    "You removed the password" : "Has eliminado la contraseña",
    "An administrator removed the password" : "Un administrador ha eliminado la contraseña",
    "{actor} added {user}" : "{actor} ha añadido a {user}",
    "You joined the conversation" : "Te has unido a la conversación",
    "{actor} joined the conversation" : "{actor} se ha unido a la conversación",
    "You added {user}" : "Has añadido a {user}",
    "{actor} added you" : "{actor} te ha añadido",
    "An administrator added you" : "Un administrador te ha añadido",
    "An administrator added {user}" : "Un administrador ha añadido a {user}",
    "You left the conversation" : "Has abandonado la conversación",
    "{actor} left the conversation" : "{actor} ha abandonado la conversación",
    "{actor} removed {user}" : "{actor} ha eliminado a {user}",
    "You removed {user}" : "Has eliminado a {user}",
    "{actor} removed you" : "{actor} te ha eliminado",
    "An administrator removed you" : "Un administrador te ha quitado",
    "An administrator removed {user}" : "Un administrador ha quitado a {user}",
    "{actor} invited {federated_user}" : "{actor} invitó a {federated_user}",
    "You invited {federated_user}" : "Ud. invitó a {federated_user}",
    "You accepted the invitation" : "Ud. aceptó la invitación",
    "{actor} invited you" : "{actor} lo ha invitado",
    "An administrator invited you" : "Un administrador lo ha invitado",
    "An administrator invited {federated_user}" : "Un administrador ha invitado a {federated_user}",
    "{federated_user} accepted the invitation" : "{federated_user} ha aceptado la invitación",
    "{actor} removed {federated_user}" : "{actor} ha eliminado a {federated_user}",
    "You removed {federated_user}" : "Ha eliminado a {federated_user}",
    "You declined the invitation" : "Ud. declinó la invitación",
    "An administrator removed {federated_user}" : "Un administrador ha eliminado a {federated_user}",
    "{federated_user} declined the invitation" : "{federated_user} ha declinado la invitación",
    "{actor} added group {group}" : "{actor} ha añadido el grupo {group}",
    "You added group {group}" : "Ud. ha añadido el grupo {group}",
    "An administrator added group {group}" : "Un administrador ha añadido el grupo {group}",
    "{actor} removed group {group}" : "{actor} ha eliminado el grupo {group}",
    "You removed group {group}" : "Ud. ha eliminado el grupo {group}",
    "An administrator removed group {group}" : "Un administrador ha eliminado el grupo {group}",
    "{actor} added team {circle}" : "{actor} añadió al equipo {circle}",
    "You added team {circle}" : "Ud. añadió al equipo {circle}",
    "An administrator added team {circle}" : "Un administrador añadió al equipo {circle}",
    "{actor} removed team {circle}" : "{actor} eliminó al equipo {circle}",
    "You removed team {circle}" : "Ud. eliminó al equipo {circle}",
    "An administrator removed team {circle}" : "Un administrador eliminó al equipo {circle}",
    "{actor} added {phone}" : "{actor} añadió a {phone}",
    "You added {phone}" : "Ud. ha añadido a {phone}",
    "An administrator added {phone}" : "Un administrador añadió a {phone}",
    "{actor} removed {phone}" : "{actor} eliminó a {phone}",
    "You removed {phone}" : "Ud. ha eliminado a {phone}",
    "An administrator removed {phone}" : "Un administrador eliminó a {phone}",
    "{actor} promoted {user} to moderator" : "{actor} ha ascendido a {user} a moderador",
    "You promoted {user} to moderator" : "Has ascendido a {user} a moderador",
    "{actor} promoted you to moderator" : "{actor} te ha ascendido a moderador",
    "An administrator promoted you to moderator" : "Un administrador te ha nombrado moderador",
    "An administrator promoted {user} to moderator" : "Un administrador ha nombrado moderador a {user}",
    "{actor} demoted {user} from moderator" : "{actor} ha degradado a {user} desde moderador",
    "You demoted {user} from moderator" : "Has degradado a {user} desde moderador",
    "{actor} demoted you from moderator" : "{actor} te ha degradado desde moderador",
    "An administrator demoted you from moderator" : "Un administrador te ha destituido como moderador",
    "An administrator demoted {user} from moderator" : "Un administrador ha destituido a {user} como moderador",
    "{actor} shared a file which is no longer available" : "{actor} compartió un archivo que ya no está disponible",
    "You shared a file which is no longer available" : "Compartiste un archivo que ya no está disponible",
    "File shares are currently not supported in federated conversations" : "La compartición de archivos no está actualmente soportada en conversaciones federadas",
    "The shared location is malformed" : "La ubicación compartida está malformada",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} ha configurado Matterbridge para sincronizar esta conversación con otros chats",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Tu has configurado Matterbridge para sincronizar esta conversación con otros chats",
    "{actor} created thread {title}" : "{actor} creó el hilo {title}",
    "You created thread {title}" : "Ud. creó el hilo {title}",
    "{actor} renamed thread {title}" : "{actor} renombró el hilo {title}",
    "You renamed thread {title}" : "Ud. renombró el hilo {title}",
    "{actor} updated the Matterbridge configuration" : "{actor} actualizó la configuración de Matterbridge",
    "You updated the Matterbridge configuration" : "Tu actualizaste la configuración de Matterbridge",
    "{actor} removed the Matterbridge configuration" : "{actor} la configuración de Matterbridge",
    "You removed the Matterbridge configuration" : "Tu eliminaste la configuración de Matterbridge",
    "{actor} started Matterbridge" : "{actor} inició Matterbridge",
    "You started Matterbridge" : "Tu iniciaste Matterbridge",
    "{actor} stopped Matterbridge" : "{actor} detuvo Matterbridge",
    "You stopped Matterbridge" : "Tu detuviste Matterbridge",
    "{actor} deleted a message" : "{actor} eliminó un mensaje",
    "You deleted a message" : "Has eliminado un mensaje",
    "{actor} edited a message" : "{actor} editó un mensaje",
    "You edited a message" : "Has editado un mensaje",
    "{actor} pinned a message" : "{actor} ha fijado un mensaje",
    "You pinned a message" : "Has fijado un mensaje",
    "{actor} unpinned a message" : "{actor} ha desfijado un mensaje",
    "Message was automatically unpinned" : "El mensaje se ha desfijado automáticamente",
    "You unpinned a message" : "Has desfijado un mensaje",
    "{actor} deleted a reaction" : "{actor} eliminó una reacción",
    "You deleted a reaction" : "Ud. ha borrado una reacción",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Ud. ha cambiado la caducidad del mensaje a %n semana","Ud. ha cambiado la caducidad del mensaje a %n semanas","Ud. ha cambiado la caducidad del mensaje a %n semanas"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Ud. ha cambiado la caducidad del mensaje a %n día","Ud. ha cambiado la caducidad del mensaje a %n días","Ud. ha cambiado la caducidad del mensaje a %n días"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Ud. ha cambiado la caducidad del mensaje a %n hora","Ud. ha cambiado la caducidad del mensaje a %n horas","Ud. ha cambiado la caducidad del mensaje a %n horas"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Ud. ha cambiado la caducidad del mensaje a %n minuto","Ud. ha cambiado la caducidad del mensaje a %n minutos","Ud. ha cambiado la caducidad del mensaje a %n minutos"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} ha cambiado la caducidad del mensaje a %n semana","{actor} ha cambiado la caducidad del mensaje a %n semanas","{actor} ha cambiado la caducidad del mensaje a %n semanas"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} ha cambiado la caducidad del mensaje a %n día","{actor} ha cambiado la caducidad del mensaje a %n días","{actor} ha cambiado la caducidad del mensaje a %n días"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} ha cambiado la caducidad del mensaje a %n hora","{actor} ha cambiado la caducidad del mensaje a %n horas","{actor} ha cambiado la caducidad del mensaje a %n horas"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} estableció la expiración de mensaje a %n minuto","{actor} estableció la expiración de mensajes a %n minutos","{actor} estableció la expiración de mensajes a %n minutos"],
    "{actor} disabled message expiration" : "{actor} ha desactivado la caducidad del mensaje",
    "You disabled message expiration" : "Ud. ha desactivado la caducidad de mensajes",
    "{actor} cleared the history of the conversation" : "{actor} ha vaciado el historial de la conversación",
    "You cleared the history of the conversation" : "Ud. ha vaciado el historial de la conversación",
    "{actor} set the conversation picture" : "{actor} ha establecido la foto de la conversación",
    "You set the conversation picture" : "Ud. ha establecido la foto de la conversación",
    "{actor} removed the conversation picture" : "{actor} ha eliminado la imagen de la conversación",
    "You removed the conversation picture" : "Ud. ha eliminado la imagen de la conversación",
    "{actor} ended the poll {poll}" : "{actor} finalizó la encuesta {poll}",
    "You ended the poll {poll}" : "Ud. ha finalizado la encuesta {poll}",
    "{actor} started the video recording" : "{actor} inició la grabación de video",
    "You started the video recording" : "Ud. ha iniciado la grabación de video",
    "{actor} stopped the video recording" : "{actor} detuvo la grabación de video",
    "You stopped the video recording" : "Ud. ha detenido la grabación de video",
    "{actor} started the audio recording" : "{actor} ha iniciado la grabación de audio",
    "You started the audio recording" : "Ud. ha iniciado la grabación de audio",
    "{actor} stopped the audio recording" : "{actor} detuvo la grabación de audio",
    "You stopped the audio recording" : "Ud. ha detenido la grabación de audio",
    "The recording failed" : "La grabación falló",
    "Someone voted on the poll {poll}" : "Alguien votó en la encuesta {poll}",
    "Message deleted by author" : "Mensaje eliminado por el autor",
    "Message deleted by {actor}" : "Mensaje eliminado por {actor}",
    "Message deleted by you" : "Has eliminado este mensaje",
    "Deleted user" : "Usuario eliminado",
    "Unknown number" : "Número desconocido",
    "Administration" : "Administración",
    "System" : "Sistema",
    "%s (guest)" : "%s (invitado)",
    "Missed call" : "Llamada perdida",
    "Unanswered call" : "Llamada sin contestar",
    "Call ended (Duration {duration})" : "Llamada finalizada (Duración {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} ha terminado la llamada (Duración {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["La llamada con %n invitado ha terminado, porque ha alcanzado la duración máxima (Duración {duration})","La llamada con %n invitados ha terminado, porque ha alcanzado la duración máxima (Duración {duration})","La llamada con %n invitados ha terminado, porque ha alcanzado la duración máxima (Duración {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Llamada con %n invitado finalizada (Duración {duration})","Llamada con %n invitados finalizada (Duración {duration})","Llamada con %n invitados finalizada (Duración {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} ha terminado la llamada con %n invitado (Duración {duration})","{actor} ha terminado la llamada con %n invitados (Duración {duration})","{actor} ha terminado la llamada con %n invitados (Duración {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada con {user1} ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "Call with {user1} ended (Duration {duration})" : "Llamada con {user1} finalizada (Duración {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} ha terminado la llamada con {user1} (Duración {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada con {user1} y {user2} ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Llamada con {user1} y {user2} finalizada (Duración {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} ha terminado la llamada con {user1} y {user2} (Duración {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada con {user1}, {user2} y {user3} ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Llamada con {user1}, {user2} y {user3} finalizada (Duración {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} ha terminado la llamada con {user1}, {user2} y {user3} (Duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada con {user1}, {user2}, {user3} y {user4} ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Llamada con {user1}, {user2}, {user3} y {user4} finalizada (Duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} ha terminado la llamada con {user1}, {user2}, {user3} y {user4} (Duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "La llamada con {user1}, {user2}, {user3}, {user4} y {user5} ha terminado, porque ha alcanzado la duración máxima (Duración {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Llamada con {user1}, {user2}, {user3}, {user4} y {user5} finalizada (Duración {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} ha terminado la llamada con {user1}, {user2}, {user3}, {user4} y {user5} (Duración {duration})",
    "Message of {user} in {conversation}" : "Mensaje de {user} en {conversation}",
    "Message of {user}" : "Mensaje de {usuario}",
    "Message of a deleted user in {conversation}" : "Mensaje de un usuario eliminado en {conversation}",
    "Talk conversations" : "Conversaciones de Talk",
    "Talk to %s" : "Hablar con %s",
    "An error occurred. Please contact your administrator." : "Ha ocurrido un error. Por favor contacte a su administrador.",
    "Storage quota exceeded" : "Se excedió la cuota de almacenamiento",
    "File not found" : "Archivo no encontrado",
    "File is not shared, or shared but not with the user" : "El archivo no está compartido, o lo está pero no con el usuario",
    "No account available to delete." : "No hay cuentas disponibles para borrar.",
    "Poll" : "Encuesta",
    "Password needs to be set" : "Es necesario establecer la contraseña",
    "Uploading the file failed" : "La subida del archivo ha fallado",
    "No image file provided" : "No se ha proporcionado un archivo de imagen",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Archivo proporcionado no válido",
    "Invalid image" : "Imagen no válida",
    "Unknown filetype" : "Extensión de archivo desconocida",
    "Talk mentions" : "Menciones en Talk",
    "More conversations" : "Más conversaciones",
    "Say hi to your friends and colleagues!" : "¡Saluda a tus amigos y colegas!",
    "No unread mentions" : "No hay menciones sin leer",
    "Call in progress" : "Llamada en curso",
    "You were mentioned" : "Te han mencionado",
    "Write to conversation" : "Escribir en la conversación",
    "Writes event information into a conversation of your choice" : "Escribe información del evento en una conversación de su elección",
    "Missing email field in header line" : "Falta el campo correo en la cabecera",
    "Following lines are invalid: %s" : "Las siguientes líneas son inválidas: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s le ha invitado a la conversación  \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Ud. fue invitado a la conversación \"%s\".",
    "Conversation invitation" : "Invitación de conversación",
    "Scheduled time" : "Hora programada",
    "Description" : "Descripción",
    "You can also dial-in via phone with the following details" : "También puedes unirte por teléfono con estos datos",
    "Dial-in information" : "Información de conexión telefónica",
    "Meeting ID" : "ID de reunión",
    "Your PIN" : "Tu PIN",
    "Click the button below to join the lobby now." : "Haga clic en el botón a continuación para unirse a la sala de espera",
    "Click the link below to join the lobby now." : "Haga clic en el botón a continuación para unirse a la sala de espera",
    "Join lobby for \"%s\"" : "Unirse a la sala de espera para \"%s\"",
    "Click the button below to join the conversation now." : "Haga clic en el botón a continuación para unirse a la conversación ahora.",
    "Click the link below to join the conversation now." : "Haga clic en el enlace a continuación para unirse a la conversación ahora.",
    "Join \"%s\"" : "Unirse a \"%s\"",
    "Meeting" : "Reunión",
    "Password request: %s" : "Petición de contraseña: %s",
    "Private conversation" : "Conversación privada",
    "Deleted user (%s)" : "Borrado el usuario (%s)",
    "Failed to upload call recording" : "Fallo al subir la grabación de la llamada",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "El servidor de grabación falló al subir la grabación de la llamada {call}. Por favor, comuníquelo a la administración.",
    "Share to chat" : "Compartir al chat",
    "Dismiss notification" : "Descartar notificación",
    "Call recording now available" : "La grabación está disponible",
    "The recording for the call in {call} was uploaded to {file}." : "La grabación para llamada en {call} se ha subido a {file}.",
    "Transcript now available" : "La transcripción está disponible",
    "The transcript for the call in {call} was uploaded to {file}." : "La transcripción para llamada en {call} se ha subido a {file}.",
    "Failed to transcript call recording" : "Fallo al transcribir la grabación de la llamada",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "El servidor falló al transcribir la grabación en {file} para la llamada {call}. Por favor, comuníquelo a la administración.",
    "Call summary now available" : "El resumen de la llamada está disponible",
    "The summary for the call in {call} was uploaded to {file}." : "El resumen de la llamada de {call} se subió a {file}.",
    "Failed to summarize call recording" : "Error al resumir la grabación de la llamada",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "El servidor ha fallado al resumir la grabación en {file} de la llamada {call}. Por favor, comuníquelo a la administración.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} le invitó a unirse a la sala {roomName} en {remoteServer}",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "{user1} invited you to a federated conversation" : "{user1} le invitó a una conversación federada",
    "Someone reacted" : "Alguien reaccionó",
    "New message" : "Nuevo mensaje",
    "Reminder" : "Recordatorio",
    "Someone mentioned you" : "Alguien te mencionó",
    "Notification" : "Notificación",
    "Someone reacted in a private conversation" : "Alguien reaccionó en una conversación privada",
    "You received a message in a private conversation" : "Recibiste un mensaje en una conversación privada",
    "Reminder in a private conversation" : "Recordatorio en una conversación privada",
    "Someone mentioned you in a private conversation" : "Alguien te mencionó en una conversación privada",
    "Notification in a private conversation" : "Notificación en una conversación privada",
    "Reminder: You in {call}" : "Recordatorio: Ud. en {call}",
    "Reminder: {user} in {call}" : "Recordatorio: {user} en {call}",
    "Reminder: Deleted user in {call}" : "Recordatorio: Se eliminó al usuario en {call}",
    "Reminder: {guest} (guest) in {call}" : "Recordatorio: {guest} (invitado) en {call}",
    "Reminder: Guest in {call}" : "Recordatorio: Invitado en {call}",
    "{user} reacted with {reaction}" : "{user} reaccionó con {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reaccionó con {reaction} en {call}",
    "Deleted user reacted with {reaction} in {call}" : "Usuario eliminado reaccionó con {reaction} en {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (invitado) reaccionó con {reaction} en {call}",
    "Guest reacted with {reaction} in {call}" : "Invitado reaccionó con {reaction} en {call}",
    "{user} in {call}" : "{user} en {call}",
    "Deleted user in {call}" : "Usuario eliminado de {call}",
    "{guest} (guest) in {call}" : "{guest} (invitado) en {call}",
    "Guest in {call}" : "Invitado en {call}",
    "{user} sent you a private message" : "{user} te ha enviado un mensaje privado",
    "{user} sent a message in conversation {call}" : "{user} ha enviado un mensaje en la conversación {call}",
    "A deleted user sent a message in conversation {call}" : "Un usuario eliminado envió un mensaje a la conversación {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (guest) envió un mensaje en la conversación {call}",
    "A guest sent a message in conversation {call}" : "Un invitado envió un mensaje a la conversación {call}",
    "{user} replied to your private message" : "{user} respondió a su mensaje privado",
    "{user} replied to your message in conversation {call}" : "{user} respondió a su mensaje privado en la conversación {call}",
    "A deleted user replied to your message in conversation {call}" : "Un usuario borrado respondió a a su mensaje en la conversación {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (guest) respondió su mensaje en la conversación {call}",
    "A guest replied to your message in conversation {call}" : "Un invitado respondió a su mensaje en la conversación {call}",
    "Reminder: You in private conversation {call}" : "Recordatorio: Ud. en la conversación privada {call}",
    "Reminder: A deleted user in private conversation {call}" : "Recordatorio: Un usuario eliminado en la conversación privada {call}",
    "Reminder: {user} in private conversation" : "Recordatorio: {user} en la conversación privada",
    "Reminder: You in conversation {call}" : "Recordatorio: Ud. en la conversación {call}",
    "Reminder: {user} in conversation {call}" : "Recordatorio: {user} en la conversación {call}",
    "Reminder: A deleted user in conversation {call}" : "Recordatorio: Un usuario eliminado en la conversación {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Recordatorio: {guest} (invitado) en la conversación {call}",
    "Reminder: A guest in conversation {call}" : "Recordatorio: Un invitado en la conversación {call}",
    "{user} reacted with {reaction} to your private message" : "{user} reaccionó con {reaction} a su mensaje privado",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} reaccionó con {reaction} a su mensaje en la conversación {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Un usuario eliminado reaccionó con {reaction} a su mensaje en la conversación {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (invitado) reaccionó con {reaction} a su mensaje en la conversación {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Un invitado reaccionó con {reaction} a su mensaje en la conversación {call}",
    "{user} mentioned you in a private conversation" : "{user} te ha mencionado en una conversación privada",
    "{user} mentioned group {group} in conversation {call}" : "el usuario {user} mencionó al grupo {group} en la conversación {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} mencionó al equipo {team} en la conversación {call}",
    "{user} mentioned everyone in conversation {call}" : "el usuario {user} mencionó a todos en la conversación {call}",
    "{user} mentioned you in conversation {call}" : "{user} te ha mencionado en {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Un usuario eliminado mencionó al grupo {group} en la conversación {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Un usuario eliminado mencionó al equipo {team} en la conversación {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Un usuario eliminado mencionó a todos en la conversación {call}",
    "A deleted user mentioned you in conversation {call}" : "Un usuario eliminado te ha mencionado en {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (invitado) mencionó al grupo {group} en la conversación {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest}(Invitado) mencionó al equipo {team} en la conversación {call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (invitado) mencionó a todos en la conversación {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (guest) te mencionó en la conversación {call}",
    "A guest mentioned group {group} in conversation {call}" : "Un invitado mencionó al grupo {group} en la conversación {call}",
    "A guest mentioned team {team} in conversation {call}" : "Un invitado mencionó al equipo {team}en la conversación {call}",
    "A guest mentioned everyone in conversation {call}" : "Un invitado mencionó a todos en la conversación {call}",
    "A guest mentioned you in conversation {call}" : "Un invitado te ha mencionado en {call}",
    "View message" : "Ver mensaje",
    "Dismiss reminder" : "Descartar recordatorio",
    "View chat" : "Ver chat",
    "{user} invited you to a group conversation: {call}" : "{user} te ha invitado a una conversación de grupo: {call}",
    "Join call" : "Unirse a la llamada",
    "Answer call" : "Contestar llamada",
    "{user} would like to talk with you" : "{user} quiere hablar contigo",
    "Call back" : "Devolver llamada",
    "You missed a call from {user}" : "Tiene una llamada perdida de {user}",
    "Accept call" : "Aceptar llamada",
    "Incoming phone call from {call}" : "Llamada telefónica de {call}",
    "You missed a phone call from {call}" : "Ud. tiene una llamada perdida de {call}",
    "A group call has started in {call}" : "Una llamada de grupo ha comenzado en {call}",
    "You missed a group call in {call}" : "Tiene una llamada de grupo perdida en {call}",
    "{email} is requesting the password to access {file}" : "{email} está solicitando la contraseña para acceder a {file}",
    "{email} tried to request the password to access {file}" : "{email} trató de solicitar la contraseña para acceder a {file}",
    "Someone is requesting the password to access {file}" : "Alguien ha solicitado la contraseña para acceder a {file}",
    "Someone tried to request the password to access {file}" : "Alguien intentó solicitar la contraseña para acceder a {file}",
    "Open settings" : "Abrir configuración",
    "Hosted signaling server added" : "Servidor de señalización alojado añadido",
    "The hosted signaling server is now configured and will be used." : "El servidor de señalización gestionado ya está configurado y en uso.",
    "Hosted signaling server removed" : "Servidor de señalización alojado eliminado",
    "The hosted signaling server was removed and will not be used anymore." : "El servidor de señalización gestionado se ha eliminado y ya no se usará.",
    "Hosted signaling server changed" : "Servidor de señalización alojado modificado",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "La cuenta del servidor de señalización gestionado ha cambiado el estado de «{oldstatus}» a «{newstatus}».",
    "pending" : "pendiente",
    "active" : "activo",
    "expired" : "caducado",
    "blocked" : "bloqueado",
    "error" : "error",
    "The certificate of {host} expires in {days} days" : "El certificado de {host} expira en {days} días",
    "The certificate of {host} expired" : "El certificado de {host} expiró",
    "Contact via Talk" : "Contactar vía Talk",
    "Open Talk" : "Abrir Talk",
    "Default" : "Predeterminado",
    "Presentation" : "Presentación",
    "Conversations" : "Conversaciones",
    "Messages in current conversation" : "Mensajes en la conversación actual",
    "{user}" : "{user}",
    "Messages" : "Mensajes",
    "{user} in {conversation}" : "{user} en {conversation}",
    "Messages in other conversations" : "Mensajes en otras conversaciones",
    "One-to-one rooms always need to show the other users avatar" : "Las salas uno a uno siempre necesitan mostrar los avatars del otro usuario",
    "Invalid emoji character" : "Carácter de emoji inválido",
    "Invalid background color" : "Color de fondo inválido",
    "Avatar image is not square" : "La imagen del avatar no es cuadrada",
    "Room {number}" : "Sala {number}",
    "Other" : "Otro",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "No ha sido posible solicitar la prueba porque el servidor de pruebas no está accesible. Inténtalo de nuevo más adelante.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Hay un problema con la autenticación de esta instancia. Es posible que no sea accesible desde fuera para verificar su URL.",
    "Something unexpected happened." : "Ha ocurrido algo inesperado.",
    "The URL is invalid." : "La URL no es válida.",
    "An HTTPS URL is required." : "Se requiere una URL HTTPS.",
    "The email address is invalid." : "La dirección de correo no es válida.",
    "The language is invalid." : "El idioma no es válido.",
    "The country is invalid." : "El país no es válido.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Hay un problema con la solicitud de la prueba. Revisa los registros para más información.",
    "Too many requests are send from your servers address. Please try again later." : "Se han enviado demasiadas solicitudes desde la dirección de tu servidor. Inténtalo de nuevo más adelante.",
    "There is already a trial registered for this Nextcloud instance." : "Ya se ha registrado una prueba para esta instancia de Nextcloud.",
    "Something unexpected happened. Please try again later." : "Ha ocurrido algo inesperado. Inténtalo de nuevo más adelante.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "No ha sido posible solicitar la prueba porque el servidor de pruebas no responde bien. Inténtalo de nuevo más adelante.",
    "Trial requested but failed to get account information. Please check back later." : "Se ha solicitado la prueba, pero no se ha obtenido la información de la cuenta. Inténtalo de nuevo más adelante.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Hay un problema con la autenticación de esta solicitud. Es posible que no que no sea accesible desde fuera para verificar su URL.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "No ha sido posible obtener información de la cuenta porque el servidor de pruebas no responde bien. Inténtalo de nuevo más adelante.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Hay un problema para obtener la información de la cuenta. Revisa los registros para más información.",
    "There is no such account registered." : "Esta cuenta no está registrada.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "No ha sido posible obtener la información de la cuenta porque el servidor de pruebas no está accesible. Inténtalo de nuevo más tarde.",
    "Deleting the hosted signaling server account failed. Please check back later." : "No ha sido posible eliminar la cuenta del servidor de señalización gestionado. Inténtalo de nuevo más tarde.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "No ha sido posible eliminar la cuenta porque el servidor de pruebas no responde bien. Inténtalo de nuevo más tarde.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Hay un problema para eliminar la cuenta. Revisa los registros para más información.",
    "Too many requests are sent from your servers address. Please try again later." : "Están llegando demasiadas solicitudes desde la dirección de tu servidor. Inténtalo de nuevo más tarde.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "No ha sido posible eliminar la cuenta porque el servidor de pruebas no está accesible. Inténtalo de nuevo más tarde.",
    "Note to self" : "Nota personal",
    "A place for your private notes, thoughts and ideas" : "Un lugar para sus notas personales, pensamientos e ideas",
    "Transcript is AI generated and may contain mistakes" : "La transcripción se genera mediante IA y puede contener errores",
    "Summary is AI generated and may contain mistakes" : "El resumen se genera mediante IA y puede contener errores",
    "Let's get started!" : "¡Comencemos!",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** es una plataforma de comunicación segura y auto-hospedada que se integra completamente de manera transparente con el ecosistema Nextcloud.\n\n#### Características principales de Nextcloud Talk\n\n* Mensajes privados y chats grupales\n* Llamadas y videollamadas\n* Archivos compartidos e integración con otras aplicaciones Nextcloud\n* Ajustes de conversación, moderación y privacidad personalizables\n* Web, escritorio y móvil (iOS y Android)\n* Comunicación privada y segura\n\nDescubra más información en la [documentación de usuario](https://docs.nextcloud.com/server/latest/user_manual/es/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Bienvenido/a a Nextcloud Talk\n\nNextcloud Talk es una aplicación de mensajería privada y potente que se integra con Nextcloud. Chatee en privado o en conversaciones grupales, colabore en llamadas de voz y video, organice seminarios web y eventos, personalice sus conversaciones y más.",
    "## 🎨 Format texts to create rich messages\n\nIn Nextcloud Talk, you can use Markdown syntax to format your messages. For example, apply **bold** or *italic* formatting, or `highlight texts as code`. You can even create tables and add headings to your text.\n\nNeed to fix a typo or change formatting? Edit your message by clicking \"Edit message\" in the message menu." : "## 🎨 De formato al texto para crear mensajes complejos\n\nEn Nextcloud Talk, puede utilizar Markdown para dar formato a sus mensajes. Por ejemplo, puede usar **negrita** o *cursiva*, y también `formato de código`. Incluso puede crear tablas o añadir encabezados a su texto.\n\n¿Quiere corregir un error o cambiar el formato? Edite su mensaje con el botón \"Editar mensaje\" en el menú de mensajes.",
    "## 🔗 Add attachments and links\n\nAttach files from your Nextcloud Hub using the \"+\" button. Share items from Files and various Nextcloud apps. Some apps even support interactive widgets, for example, the Text app." : "## 🔗 Añada archivos adjuntos y enlaces\n\nAdjunte archivos desde Nextcloud Hub mediante el botón \"+\". Comparta recursos desde Archivos y varias apps de Nextcloud. Algunas apps le permiten crear widgets interactivos, como por ejemplo, la aplicación Texto.",
    "## 💭 Let the conversations flow: mention users, react to messages and more\n\nYou can mention everybody in the conversation by using %s or mention specific participants by typing \"@\" and picking their name from the list." : "## 💭 Deje que las conversaciones fluyan: mencione usuarios, reaccione a mensajes y más\n\nPuede mencionar a todos en la conversación utilizando %s o a participantes específicos escribiendo \"@\" y seleccionando su nombre de la lista.",
    "You can reply to messages, forward them to other chats and people, or copy message content." : "Puede responder a mensajes, reenviarlos a otras conversaciones y personas, ó, copiar el contenido del mensaje.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Haga más con el Selector Inteligente\n\nSimplemente escriba \"/\" o vaya al menú \"+\" para abrir el Selector Inteligente, donde podrá adjuntar distintos tipos de contenido a sus mensajes. Puede configurar el Selector Inteligente para que pueda insertar recursos de tus apps de Nextcloud, GIFs, ubicaciones, texto generado por IA y mucho más.",
    "## ⚙️ Manage conversation settings\n\nIn the conversation menu, you can access various settings to manage your conversations, such as:\n* Edit conversation info\n* Manage notifications\n* Apply numerous moderation rules\n* Configure access and security\n* Enable bots\n* and more!" : "## ⚙️ Gestione los ajustes de la conversación\n\nEn el menú de la conversación, puede acceder a varios ajustes para gestionar sus conversaciones, como:\n* Editar información de la conversación\n* Gestionar notificaciones\n* Aplicar varias reglas de moderación\n* Configurar el acceso y la seguridad\n* Activar bots\n* ¡Y más!",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Emiratos Árabes Unidos",
    "Afghanistan" : "Afganistán",
    "Antigua and Barbuda" : "Antigua y Barbuda",
    "Anguilla" : "Anguila",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Antarctica" : "Antártida",
    "Argentina" : "Argentina",
    "American Samoa" : "Samoa Estadounidense",
    "Austria" : "Austria",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Åland Islands" : "Islas Åland",
    "Azerbaijan" : "Azerbaiyán",
    "Bosnia and Herzegovina" : "Bosnia y Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Bélgica",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgaria",
    "Bahrain" : "Baréin",
    "Burundi" : "Burundi",
    "Benin" : "Benín",
    "Saint Barthélemy" : "San Bartolomé",
    "Bermuda" : "Bermudas",
    "Brunei Darussalam" : "Brunéi Darusalam",
    "Bolivia, Plurinational State of" : "Bolivia, Estado Plurinacional de",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, San Eustaquio y Saba",
    "Brazil" : "Brasil",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bután",
    "Bouvet Island" : "Isla Bouvet",
    "Botswana" : "Botsuana",
    "Belarus" : "Bielorrusia",
    "Belize" : "Belice",
    "Canada" : "Canadá",
    "Cocos (Keeling) Islands" : "Islas Cocos (Keeling)",
    "Congo, the Democratic Republic of the" : "Congo, República Democrática del",
    "Central African Republic" : "República Centroafricana",
    "Congo" : "Congo",
    "Switzerland" : "Suiza",
    "Côte d'Ivoire" : "Costa de Marfil",
    "Cook Islands" : "Islas Cook",
    "Chile" : "Chile",
    "Cameroon" : "Camerún",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curazao",
    "Christmas Island" : "Isla de Navidad",
    "Cyprus" : "Chipre",
    "Czechia" : "Chequia",
    "Germany" : "Alemania",
    "Djibouti" : "Yibuti",
    "Denmark" : "Dinamarca",
    "Dominica" : "Dominica",
    "Dominican Republic" : "República Dominicana",
    "Algeria" : "Argelia",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estonia",
    "Egypt" : "Egipto",
    "Western Sahara" : "Sáhara Occidental",
    "Eritrea" : "Eritrea",
    "Spain" : "España",
    "Ethiopia" : "Etiopía",
    "Finland" : "Finlandia",
    "Fiji" : "Fiyi",
    "Falkland Islands (Malvinas)" : "Islas Malvinas (Falkland)",
    "Micronesia, Federated States of" : "Micronesia, Estados Federados de",
    "Faroe Islands" : "Islas Faroe",
    "France" : "Francia",
    "Gabon" : "Gabón",
    "United Kingdom of Great Britain and Northern Ireland" : "Reino Unido de la Gran Bretaña e Irlanda del Norte",
    "Grenada" : "Granada",
    "Georgia" : "Georgia",
    "French Guiana" : "Guyana Francesa",
    "Guernsey" : "Guernsey",
    "Ghana" : "Gana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenlandia",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadalupe",
    "Equatorial Guinea" : "Guinea Ecuatorial",
    "Greece" : "Grecia",
    "South Georgia and the South Sandwich Islands" : "Islas Georgias del Sur y Sandwich del Sur",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Isla Heard e Islas McDonald",
    "Honduras" : "Honduras",
    "Croatia" : "Croacia",
    "Haiti" : "Haití",
    "Hungary" : "Hungría",
    "Indonesia" : "Indonesia",
    "Ireland" : "Irlanda",
    "Israel" : "Israel",
    "Isle of Man" : "Isla de Man",
    "India" : "India",
    "British Indian Ocean Territory" : "Territorio Británico del Océano Índico",
    "Iraq" : "Iraq",
    "Iran, Islamic Republic of" : "Irán, República Islámica de",
    "Iceland" : "Islandia",
    "Italy" : "Italia",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordania",
    "Japan" : "Japón",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirguizistán",
    "Cambodia" : "Camboya",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoras",
    "Saint Kitts and Nevis" : "San Cristóbal y Nieves",
    "Korea, Democratic People's Republic of" : "Corea, República Democrática Popular de",
    "Korea, Republic of" : "Corea, República de",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Islas Caimán",
    "Kazakhstan" : "Kazajistán",
    "Lao People's Democratic Republic" : "República Democrática Popular de Laos",
    "Lebanon" : "Líbano",
    "Saint Lucia" : "Santa Lucía",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesoto",
    "Lithuania" : "Lituania",
    "Luxembourg" : "Luxemburgo",
    "Latvia" : "Letonia",
    "Libya" : "Libia",
    "Morocco" : "Marruecos",
    "Monaco" : "Mónaco",
    "Moldova, Republic of" : "Moldavia, República de",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "San Martín (parte francesa)",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Islas Marshall",
    "North Macedonia" : "Macedonia del norte",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolia",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Islas Marianas del Norte",
    "Martinique" : "Martinica",
    "Mauritania" : "Mauritania",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauricio",
    "Maldives" : "Maldivas",
    "Malawi" : "Malawi",
    "Mexico" : "México",
    "Malaysia" : "Malasia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nueva Caledonia",
    "Niger" : "Níger",
    "Norfolk Island" : "Isla Norfolk",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Países Bajos",
    "Norway" : "Noruega",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nueva Zelanda",
    "Oman" : "Omán",
    "Panama" : "Panamá",
    "Peru" : "Perú",
    "French Polynesia" : "Polinesia Francesa",
    "Papua New Guinea" : "Papúa Nueva Guinea",
    "Philippines" : "Filipinas",
    "Pakistan" : "Pakistán",
    "Poland" : "Polonia",
    "Saint Pierre and Miquelon" : "San Pedro y Miquelón",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina, Estado de",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Catar",
    "Réunion" : "Reunión",
    "Romania" : "Rumanía",
    "Serbia" : "Serbia",
    "Russian Federation" : "Rusia, Federación de",
    "Rwanda" : "Ruanda",
    "Saudi Arabia" : "Arabia Saudí",
    "Solomon Islands" : "Islas Salomón",
    "Seychelles" : "Seychelles",
    "Sudan" : "Sudán",
    "Sweden" : "Suecia",
    "Singapore" : "Singapur",
    "Saint Helena, Ascension and Tristan da Cunha" : "Santa Elena, Ascensión y Tristán de Acuña",
    "Slovenia" : "Eslovenia",
    "Svalbard and Jan Mayen" : "Svalbard y Jan Mayen",
    "Slovakia" : "Eslovaquia",
    "Sierra Leone" : "Sierra Leona",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "Sudán del Sur",
    "Sao Tome and Principe" : "Santo Tomé y Príncipe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "San Martín (parte holandesa)",
    "Syrian Arab Republic" : "República Árabe Siria",
    "Eswatini" : "Swazilandia",
    "Turks and Caicos Islands" : "Islas Turcos y Caicos",
    "Chad" : "Chad",
    "French Southern Territories" : "Territorios Franceses del Sur",
    "Togo" : "Togo",
    "Thailand" : "Tailandia",
    "Tajikistan" : "Tayikistán",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor Oriental",
    "Turkmenistan" : "Turkmenistán",
    "Tunisia" : "Túnez",
    "Tonga" : "Tonga",
    "Turkey" : "Turquía",
    "Trinidad and Tobago" : "Trinidad y Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwán, Provincia de China",
    "Tanzania, United Republic of" : "Tanzania, República Unida de",
    "Ukraine" : "Ucrania",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Islas Ultramarinas Menores Estadounidenses",
    "United States of America" : "Estados Unidos de América",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistán",
    "Holy See" : "Estado Vaticano",
    "Saint Vincent and the Grenadines" : "San Vicente y las Granadinas",
    "Venezuela, Bolivarian Republic of" : "Venezuela, República Bolivariana de",
    "Virgin Islands, British" : "Islas Vírgenes (Británicas)",
    "Virgin Islands, U.S." : "Islas Vírgenes (U.S.)",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis y Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sudáfrica",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabue",
    "Background blur" : "Desenfocar fondo",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "No se ha podido comprobar el soporte para cargar WASM. Por favor, compruebe manualmente si su servidor web sirve archivos '.wasm'.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Su servidor web no está configurado para entregar archivos `.wasm` correctamente. Esto suele ser un problema relacionado con la configuración de Nginx. Asímismo, el desenfoque de fondo también necesita un ajuste para entregar archivos `.wasm`. Compare su configuración de Nginx con la configuración recomendada en nuestra documentación.",
    "Talk configuration values" : "Valores de configuración de Talk",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Limitar la duración de las llamadas solo está soportado con el cron del sistema. Por favor, habilite el cron de sistema o elimine la configuración `max_call_duration`.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Los valores bajos del ajuste `max_call_duration` (que actualmente es %d) no pueden ser impuestos por limitaciones técnicas. La tarea en segundo plano solo se ejecuta cada 5 minutos, así que úselo bajo su propio riesgo.",
    "Federation" : "Federación",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Es altamente recomendable configurar \"memcache.locking\" cuando la Federación de Talk está habilitada.",
    "High-performance backend" : "Motor de alto rendimiento",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "No se ha configurado un backend de alto rendimiento - Ejecutar Nextcloud Talk sin utiliizar el backend de alto rendimiento solo escala con llamadas pequeñas (máx. 2-3 participantes). Por favor, configure un backend de alto rendimiento para asegurarse que las llamadas con múltiples participantes funcionen sin interrupciones.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Ejecutar el backend de alto rendimiento en el modo \"conversation_cluster\" está discontinuado y no será soportado en la próxima versión. El backend de alto rendimiento actualmente soporta clustering verdadero y debería ser utilizado en su lugar.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Definir múltiples backends de alto rendimiento está discontinuado y no será soportado en la próxima versión. En su lugar, debería configurarse un balanceador de carga con varios servidores de señalización en clúster, y configurado en los ajustes de Talk.",
    "The stored public key for used algorithm %1$s does not match the stored private key. Run %2$s to fix the issue." : "La llave pública almacenada para el algoritmo %1$s no coincide con la llave privada almacenada. Ejecute %2$s para corregir el problema.",
    "High-performance backend not configured correctly. Run %s for details." : "El backend de alto rendimiento no ha sido configurado correctamente. Ejecute %s para ver los detalles.",
    "High-performance backend not configured correctly" : "El backend de alto rendimiento no ha sido configurado correctamente",
    "Error: Cannot connect to server" : "Error: No se puede conectar con el servidor",
    "Error: Server did not respond with proper JSON" : "Error: El servidor no ha respondido con JSON correcto",
    "Error: Certificate expired" : "Error: Certificado caducado",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Error: los relojes de los servidores Nextcloud y el backend de alto rendimiento están desincronizados. Por favor, asegúrese de que ambos servidores están conectados a un servidor de sincronización de hora o sincronice sus relojes manualmente.",
    "Could not get version" : "No se pudo obtener la versión",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Error: Versión en ejecución: {versión}; El servidor necesita ser actualizado para ser compatible con esta versión de Talk",
    "Error: Server responded with: {error}" : "Error: El servidor ha respondido con: {error}",
    "Error: Unknown error occurred" : "Error: Ha sucedido un error desconocido",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Advertencia: Versión en ejecución: {version}; El servidor no soporta todas las características de esta versión de Talk, características que faltan: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Es altamente recomendado que se configure un caché de memoria cuando se ejecuta Nextcloud Talk con un backend de alto rendimiento.",
    "Client Push" : "Client Push",
    "Client Push is installed, this improves the punctuality of Talk notifications." : "Client Push está instalado, esto mejora la puntualidad de las notificaciones de Talk.",
    "{notify_push} is not installed. This may lead to delayed Talk notifications." : "{notify_push} no está instalado. Esto puede llevar a retrasos en las notificaciones de Talk.",
    "Recording backend" : "Backend de grabación",
    "Using the recording backend requires a High-performance backend." : "Usar el backend de grabación requiere un backend de alto rendimiento.",
    "No recording backend configured" : "No se ha configurado un backend de grabación",
    "SIP configuration" : "Configuración SIP",
    "Using the SIP functionality requires a High-performance backend." : "Usar la funcionalidad SIP requiere un backend de alto rendimiento.",
    "No SIP backend configured" : "No se ha configurado un backend SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Fecha no válida, el formato de las fechas debe ser AAAA-MM-DD",
    "Conversation not found" : "Conversación no encontrada",
    "Path is already shared with this conversation" : "La ruta ya está compartida con esta conversación",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video y audio conferencias mediante WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video & audio conferencias usando WebRTC\n\n* 💬 **Chat** Nextcloud Talk viene con un chat de texto simple, permitiéndole compartir o subir archivos desde la app de Archivos de Nextcloud, o, desde su dispositivo local y mencionar a otros participantes.\n* 👥 **¡Llamadas privadas, grupales, públicas y protegidas por contraseña!** Invite a alguien, a un grupo o envíe un enlace público para invitar a una llamada.\n* 🌐 **Chats federados** Chatee con otros usuarios de Nextcloud en sus servidores\n* 💻 **¡Compartir pantalla!** Comparta su pantalla con los participantes de su llamada.\n* 🚀 **Integración con otras apps de Nextcloud** como Archivos, Calendario, estados de usuario, Tablero, Flujos, Mapas, Seleccionador inteligente, Contactos, Tarjetas, y muchas mas.\n* 🌉 **Sincronización con otras soluciones de mensajería** Estando [Matterbridge](https://github.com/42wim/matterbridge/) integrado en Talk, puede fácilmente sincronizar un sinnúmero de otras soluciones de chat con Talk de Nextcloud y viceversa.",
    "Leave call" : "Dejar llamada",
    "Navigating away from the page will leave the call in {conversation}" : "Navegar fuera de esta página colgará la llamada en {conversation}",
    "Stay in call" : "Permanecer en la llamada",
    "Error occurred when getting the conversation information" : "Ocurrió un error al obtener la información de la conversación",
    "Discuss this file" : "Discutir sobre este archivo",
    "Share this file with others to discuss it" : "Compartir esta archivo con otros para debatirlo",
    "Share this file" : "Compartir este archivo",
    "Join conversation" : "Unirse a la conversación",
    "This conversation is password-protected." : "Esta conversación está protegida con contraseña.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "Hemos detectado múltiples intentos fallidos de inicio de sesión desde su IP. Por lo tanto, su siguiente inicio de sesión se podría retrasar hasta 30 segundos. ",
    "The password is wrong. Try again." : "La contraseña es errónea. Vuelve a intentarlo.",
    "Password" : "Contraseña",
    "Submit" : "Enviar",
    "Error requesting the password." : "Error al solicitar la contraseña",
    "Request password" : "Solicitar contraseña",
    "This conversation has ended" : "Esta conversación ha finalizado",
    "Error occurred when joining the conversation" : "Se ha producido un error al unirse a la conversación",
    "Close Talk sidebar" : "Cerrar la barra lateral de Talk",
    "Open Talk sidebar" : "Abrir la barra lateral de Talk",
    "Everyone" : "Todo el mundo",
    "Users and moderators" : "Usuarios y moderadores",
    "Moderators only" : "Sólo moderadores",
    "Disable calls" : "Deshabilitar llamadas",
    "Save changes" : "Guardar cambios",
    "Saving …" : "Guardando …",
    "Saved!" : "Guardado",
    "Limit to groups" : "Limitar para grupos",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Cuando se ha seleccionado al menos un grupo, solo personas de los grupos seleccionados pueden ser parte de las conversaciones.",
    "Guests can still join public conversations." : "Los invitados todavía pueden unirse a conversaciones públicas",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Los usuarios que ya no puedan usar Talk serán listados como participantes en sus conversaciones previas y también se mantendrán sus mensajes de chat.",
    "Limit using Talk" : "Límite al usar Talk",
    "Limit creating a public and group conversation" : "Límite al crear una conversación pública y de grupo",
    "Limit creating conversations" : "Límite al usar conversaciones",
    "Limit starting a call" : "Límite al comenzar una llamada",
    "Limit starting calls" : "Límite al comenzar llamadas",
    "When a call has started, everyone with access to the conversation can join the call." : "Cuando una llamada ha comenzado, todos los que tienen acceso a la conversación pueden unirse a la llamada.",
    "The following bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "Se han instalado los siguientes bots en este servidor. En la documentación puede encontrar detalles sobre cómo {linkstart1} crear su propio bot {linkend} o una {linkstart2} lista de bots {linkend} para habilitar en su servidor.",
    "No bots are installed on this server. In the documentation you can find details how to {linkstart1}build your own bot{linkend} or a {linkstart2}list of bots{linkend} to enable on your server." : "No se han instalado bots en este servidor. En la documentación puede encontrar detalles sobre cómo {linkstart1} crear su propio bot {linkend} o una {linkstart2} lista de bots {linkend} para habilitar en su servidor.",
    "Description is not provided" : "No se ha dado una descripción",
    "Locked for moderators" : "Bloqueado para moderadores",
    "Enabled" : "Habilitado",
    "Disabled" : "Desactivado",
    "Bots settings" : "Configuración de bots",
    "State" : "Estado",
    "Name" : "Nombre",
    "Last error" : "Último error",
    "Total errors count" : "Recuento total de errores",
    "Find more bots" : "Encontrar más bots",
    "Trusted servers can be configured at {linkstart}Sharing settings page{linkend}." : "Los servidores de confianza pueden ser configurados en {linkstart}La página de ajustes{linkend}.",
    "Beta" : "Beta",
    "Federated chats and calls work already. Attachment handling is coming in a future version." : "Los chats y llamadas federadas ya funcionan. La gestión de adjuntos llegará en una versión futura.",
    "Enable Federation in Talk app" : "Habilitar federación en la app Talk",
    "Permissions" : "Permisos",
    "Allow users to be invited to federated conversations" : "Permitir a los usuarios ser invitados a conversaciones federadas",
    "Allow users to invite federated users into conversation" : "Permitir a los usuarios invitar a los usuarios federados en la conversación",
    "Only allow to federate with trusted servers" : "Solo permitir la federación entre servidores de confianza",
    "When at least one group is selected, only people of the listed groups can invite federated users to conversations." : "Cuando se ha seleccionado al menos un grupo, solo personas de los grupos listados pueden invitar a los usuarios federados a las conversaciones.",
    "Groups allowed to invite federated users" : "Grupos que tienen permitido invitar a usuarios federados",
    "Select groups …" : "Seleccione los grupos …",
    "All messages" : "Todos los mensajes",
    "@-mentions only" : "Solo menciones con @",
    "Off" : "Off",
    "General settings" : "Ajustes generales",
    "Default notification settings" : "Configuración por defecto de notificaciones",
    "Default group notification" : "Notificación por defecto de grupo",
    "Default group notification for new groups" : "Notificación por defecto para grupos nuevos",
    "Integration into other apps" : "Integración en otras aplicaciones",
    "Allow conversations on files" : "Permitir conversaciones en archivos",
    "Allow conversations on public shares for files" : "Permitir conversaciones en recursos compartidos para archivos",
    "End-to-end encrypted calls" : "Llamadas cifradas de extremo a extremo",
    "Enable encryption" : "Habilitar cifrado",
    "End-to-end encrypted calls with a configured SIP bridge require a newer version of the High-performance backend and SIP bridge." : "Las llamadas cifradas de extremo a extremo con un puente SIP configurado necesitan una nueva versión del backend de alto rendimiento y del puente SIP.",
    "Mobile clients do not support end-to-end encrypted calls at the moment." : "Los clientes móviles no soportan las llamadas cfiradas de extremo a extremo en el momento.",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Al pulsar el botón de arriba, los datos del formulario se enviarán a los servidores de Struktur AG. Puedes encontrar más información en {linkstart}spreed.eu{linkend}.",
    "Pending" : "Pendiente",
    "Error" : "Error",
    "Blocked" : "Bloqueado",
    "Active" : "Activo",
    "Expired" : "Terminada",
    "Never" : "Nunca",
    "The trial could not be requested. Please try again later." : "No se ha podido solicitar la prueba. Inténtalo de nuevo más adelante.",
    "The account could not be deleted. Please try again later." : "No se ha podido eliminar la cuenta. Inténtalo de nuevo más adelante.",
    "Hosted High-performance backend" : "Backend de alto rendimiento alojado",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Nuestro asociado Struktur AG ofrece un servicio en el que puedes solicitar un servidor de señalización gestionado. Para ello, solo tienes que rellenar el formulario a continuación y tu Nextcloud enviará la solicitud. Cuando el servidor esté configurado, las credenciales se rellenarán automáticamente. Esto sobrescribirá los ajustes actuales del servidor de señalización.",
    "If your high-performance backend account includes STUN and/or TURN functionality, the settings will be updated accordingly." : "Si su backend de alto rendimiento incluye funcionalidad STUN y/o TURN, los ajustes serán adecuadamente actualizados ",
    "URL of this Nextcloud instance" : "URL de esta instancia de Nextcloud",
    "Full name of the user requesting the trial" : "Nombre completo del usuario que solicita la prueba",
    "Email of the user" : "Email del usuario",
    "Language" : "Idioma",
    "Country" : "País",
    "Request signaling server trial" : "Solicitar prueba del servidor de señalización",
    "You can see the current status of your hosted signaling server in the following table." : "Puedes ver el estado actual de tu servidor de señalización gestionado en la siguiente tabla.",
    "Status" : "Estado",
    "Created at" : "Creado el",
    "Expires at" : "Caduca el",
    "Limits" : "Límites",
    "STUN included" : "STUN incluido",
    "Yes" : "Sí",
    "No" : "No",
    "TURN included" : "TURN incluido",
    "Delete the signaling server account" : "Eliminar la cuenta del servidor de señalización",
    "_%n user_::_%n users_" : ["%n usuario","%n usuarios","%n usuarios"],
    "Installed version: {version}" : "Versión instalada: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Puede instalar Matterbridge para enlazar Nextcloud Talk con algunos otros servicios, visite su {linkstart1}página de GitHub{linkend} para más detalles. La descarga e instalación de la aplicación puede llevar un tiempo. En caso de que falle por tiempo de espera, haga la instalación manualmente desde la {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary has incorrect permissions. Please make sure the Matterbridge binary file is owned by the correct user and can be executed. It can be found in \"/…/nextcloud/apps/talk_matterbridge/bin/\"." : "El archivo binario de Matterbridge tiene permisos incorrectos. Por favor, asegúrese de que el archivo binario de Matterbridge pertenece al usuario correcto y se puede ejecutar. Este puede encontrarse en \"/…/nextcloud/apps/talk_matterbridge/bin/\".",
    "Matterbridge binary was not found or couldn't be executed." : "El binario de Matterbridge no se ha encontrado o no se ha podido ejecutar.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "También puede configurar manualmente la ruta al binario de Matterbridge mediante la configuración. Consulte la {linkstart}documentación de integración de Matterbridge{linkend} para más información.",
    "Downloading …" : "Descargando …",
    "Install Talk Matterbridge" : "Instalar Talk Matterbridge",
    "An error occurred while installing the Matterbridge app" : "Ocurrió un error mientras se instalaba la app Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Ocurrió un error mientras se instalaba Matterbridge para Talk. Por favor, instale el mismo manualmente",
    "Failed to execute Matterbridge binary." : "Fallo al ejecutar el binario de Matterbridge.",
    "Matterbridge integration" : "Integración con Matterbridge",
    "Enable Matterbridge integration" : "Activar integración con Matterbridge",
    "Status: Checking connection" : "Estado: Comprobando conexión",
    "OK: Running version: {version}" : "OK: Versión en uso: {version}",
    "Error: Server seems to be a Signaling server" : "Error: el servidor parece ser un servidor de señalización",
    "Error: System times of Nextcloud server and Recording backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Error: los relojes de los servidores Nextcloud y el backend de grabación están desincronizados. Por favor, asegúrese de que ambos servidores están conectados a un servidor de sincronización de hora o sincronice sus relojes manualmente.",
    "Recording backend URL" : "URL del backend de grabación",
    "Validate SSL certificate" : "Validar certificado SSL",
    "Delete this server" : "Eliminar este servidor",
    "Test this server" : "Probar este servidor",
    "Disabled for all calls" : "Deshabilitado para todas las llamadas",
    "Enabled for all calls" : "Habilitado para todas las llamadas",
    "Configurable on conversation level by moderators" : "Configurable a nivel de conversación por los moderadores",
    "The PHP settings \"upload_max_filesize\" or \"post_max_size\" only will allow to upload files up to {maxUpload}." : "Los ajustes PHP \"upload_max_filesize\" ó \"post_max_size\" sólo le permitirán cargar archivos de hasta {maxUpload}.",
    "Recording backend settings saved" : "Se guardaron las configuraciones del backend de grabación",
    "Moderators will be allowed to enable consent on conversation level. The consent to be recorded will be required for each participant before joining every call in this conversation." : "A los moderadores les será permitido habilitar el consentimiento a nivel de conversación. El consentimiento para ser grabado le será requerido a cada participante antes de unirse a cada una de las llamadas en esta conversación.",
    "The consent to be recorded will be required for each participant before joining every call." : "El consentimiento para ser grabado le será requerido a cada participante antes de unirse a cada llamada.",
    "The consent to be recorded is not required." : "El consentimiento para ser grabado no es requerido.",
    "Recording backend configuration is only possible with a High-performance backend." : "La configuración del backend de grabación solo es posible con el backend de alto rendimiento.",
    "Add a new recording backend server" : "Añadir un nuevo servidor de backend de grabación",
    "Shared secret" : "Secreto compartido",
    "Recording consent" : "Consentimiento de grabación",
    "Recording transcription" : "Grabando transcripción",
    "Automatically transcribe call recordings with a transcription provider" : "Transcribe automáticamente las llamadas grabadas con un proveedor de transcripciones",
    "Automatically summarize call recordings with transcription and summary providers" : "Resume automáticamente las llamadas grabadas con proveedores de transcripción y resumen",
    "SIP configuration saved!" : "¡Configuración SIP guardada!",
    "SIP configuration is only possible with a High-performance backend." : "La configuración SIP solo es posible con un backend de alto rendimiento.",
    "Enable SIP Dial-out option" : "Habilitar opción para para llamadas SIP salientes",
    "Signaling server needs to be updated to supported SIP Dial-out feature." : "El servidor de señalización debe ser actualizado para que tenga soporte para llamadas SIP salientes",
    "Do not show SIP Dial-out caller number" : "No mostrar el número telefónico en llamadas SIP salientes",
    "Anonymous number should appear as \"unknown\" or \"withheld number\" to call recipient" : "El número anónimo debe aparecer como \"desconocido\" o \"número privado\" al recipiente de la llamada",
    "Dial-out number" : "Número de llamada saliente",
    "E164 formatted number used as a fallback caller number for outgoing calls" : "Número en formato E164 utilizado como número alternativo para llamadas salientes",
    "Dial-out prefix" : "Prefijo para llamadas salientes",
    "Prefix to configured user number for outgoing calls (default is `+`)" : "Prefijo para el número configurado del usuario para llamadas salientes (el predeterminado es `+`)",
    "Restrict SIP configuration" : "Restringir la configuración SIP",
    "Enable SIP configuration" : "Habilitar configuración SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Solo los usuarios de los siguientes grupos pueden permitir SIP en las conversaciones que moderen",
    "Phone number (Country)" : "Número de teléfono (País)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Esta información se envía por correo electrónico y se muestra en la barra lateral a todos los participantes.",
    "Nextcloud base URL" : "URL base de Nextcloud",
    "Talk Backend URL" : "URL del backend Talk",
    "WebSocket URL" : "URL de WebSocket",
    "Available features" : "Características disponibles",
    "Error: Websocket connection failed" : "Error: La conexión Websocket falló",
    "Error code" : "Código de error",
    "Error message" : "Mensaje de error",
    "Error: Websocket connection failed. Check browser console" : "Error: la conexión Websocket ha fallado. Compruebe la consola del navegador",
    "High-performance backend URL" : "URL del motor de alto rendimiento",
    "Missing High-performance backend warning hidden" : "La advertencia de falta de backend de alto rendimiento está oculta",
    "High-performance backend settings saved" : "Se guardaron las configuraciones del backend de alto rendimiento",
    "Nextcloud Talk setup not complete" : "La configuración de Nextcloud Talk no está completa",
    "Please note that in calls with more than 2 participants without the High-performance backend, participants will most likely experience connectivity issues and cause high load on participating devices." : "Por favor, tenga en cuenta que en llamadas con más de 2 participantes sin el backend de alto rendimiento, los participantes podrían experimentar problemas de conectividad y causará una carga de trabajo alta en los dispositivos participantes.",
    "Install the High-performance backend to ensure calls with multiple participants work seamlessly." : "Instale el backend de alto rendimiento para asegurarse de que las llamadas con múltiples participantes funcionen sin interrupciones.",
    "Nextcloud portal" : "Portal Nextcloud",
    "Quick installation guide" : "Guía de instalación rápida",
    "The High-performance backend is required for calls and conversations with multiple participants. Without the backend, all participants have to upload their own video individually for each other participant, which will most likely cause connectivity issues and a high load on participating devices." : "El backend de alto rendimiento es requerido para llamadas y conversaciones con múltiples participantes. Sin este backend, todos los participantes tienen que enviar su vídeo individualmente a todos los demás participantes, lo que les creará, probablemente, problemas de conectividad y una carga de trabajo alta en sus dispositivos.",
    "It is highly recommended to set up a distributed cache when using Nextcloud Talk with a High-performance backend." : "Es altamente recomendable configurar una caché distribuida al utilizar Nextcloud Talk con un backend de alto rendimiento.",
    "Add High-performance backend server" : "Añadir un servidor backend de alto rendimiento",
    "Warn about connectivity issues in calls with more than 2 participants" : "Advertir sobre problemas de conectividad en llamadas con más de 2 participantes.",
    "STUN server URL" : "URL del servidor STUN",
    "The server address is invalid" : "La dirección del servidor no es válida",
    "STUN settings saved" : "Configuraciones STUN guardadas",
    "STUN servers" : "Servidores STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Un servidor STUN se usa para determinar la dirección IP pública de participantes que estén tras un router.",
    "Add a new STUN server" : "Agregar un servidor STUN nuevo ",
    "{schema} scheme must be used with a domain" : "El esquema {schema} debe usarse con un dominio",
    "{option1} and {option2}" : "{option1} y {option2}",
    "{option} only" : "Solo {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: El servidor TURN ha devuelto candidatos ICE con éxito",
    "Error: No working ICE candidates returned by the TURN server" : "Error: El servidor TURN no ha devuelto candidatos ICE que funcionen",
    "Testing whether the TURN server returns ICE candidates" : "Probando si el servidor TURN devuelve candidatos ICE",
    "TURN server schemes" : "Esquemas de servidor TURN (Traversal Using Relays around NAT)",
    "TURN server URL" : "URL del servidor TURN",
    "TURN server secret" : "Secreto del servidor TURN",
    "TURN server protocols" : "Protocolos de servidor TURN",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Un servidor TURN se utiliza para hacer de proxy del tráfico de los participantes trás un firewall. Si los participantes individuales no pueden conectarse a otros, lo más probable es que se necesite un servidor TURN. Consulte {linkstart}esta documentación{linkend} para obtener instrucciones de configuración.",
    "TURN settings saved" : "Configuraciones TURN guardadas",
    "TURN servers" : "Servidores TURN.",
    "Add a new TURN server" : "Agregar un servidor TURN nuevo ",
    "Failed" : "Falló",
    "OK" : "OK",
    "Checking …" : "Comprobando …",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Fallo: WebAssembly está deshabilitado o no está soportado por este navegador. Por favor, activa WebAssembly o usa un navegador con soporte para que se haga la comprobación.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Fallo: los archivos \".wasm\" y \".tflite\" no han sido devueltos correctamente por el servidor web. Por favor compruebe la sección \"Requisitos del sistema\" en la documentación de Talk.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: los archivos \".wasm\" y \".tflite\" han sido devueltos correctamente por el servidor web",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Parece que la configuración de PHP y Apache no es compatible. Por favor, tenga en cuenta que PHP solo puede usarse con el módulo MPM_PREFORK y que PHP-FPM solo puede usarse con el módulo MPM_EVENT.",
    "Web server setup checks" : "Comprobaciones de la configuración del servidor web",
    "Files required for virtual background can be loaded" : "Los archivos necesarios para el fondo virtual se pueden cargar",
    "Federated user" : "Usuario federado",
    "Assign participants to rooms" : "Asignar participantes a salas",
    "Configure breakout rooms" : "Configurar salas de grupos",
    "Number of breakout rooms" : "Número de salas de grupos",
    "You can create from 1 to 20 breakout rooms." : "Puede crear desde 1 a 20 salas de grupo.",
    "Assignment method" : "Método de asignación",
    "Automatically assign participants" : "Asignar participantes automáticamente",
    "Manually assign participants" : "Asignar participantes manualmente",
    "Allow participants to choose" : "Permitir a los participantes escoger",
    "Create rooms" : "Crear salas",
    "Confirm" : "Confirmar",
    "Create breakout rooms" : "Crear salas de grupos",
    "Reset" : "Restablecer",
    "Delete breakout rooms" : "Eliminar salas de grupos",
    "Room {roomNumber}" : "Sala {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Las salas de grupos y las configuraciones actuales se perderán",
    "Cancel" : "Cancelar",
    "Unassigned participants" : "Participantes no asignados",
    "Back" : "Volver",
    "Assign" : "Asignar",
    "Add participant \"{user}\"" : "Añadir participante «{user}»",
    "Now" : "Ahora",
    "Invalid calendar selected" : "Se seleccionó un calendario inválido",
    "Invalid start time selected" : "Se seleccionó una hora de inicio inválida",
    "Invalid end time selected" : "Se seleccionó una hora de finalización inválida",
    "Unknown error occurred" : "Ha ocurrido un error desconocido",
    "Sending no invitations" : "No se enviarán invitaciones",
    "{participant0} will receive an invitation" : "{participant0} recibirá una invitación",
    "{participant0} and {participant1} will receive invitations" : "{participant0} y {participant1} recibirán invitaciones",
    "_{participant0}, {participant1} and %n other will receive invitations_::_{participant0}, {participant1} and %n others will receive invitations_" : ["{participant0}, {participant1} y %n otro recibirán invitaciones","{participant0}, {participant1} y %n otros recibirán invitaciones","{participant0}, {participant1} y %n otros recibirán invitaciones"],
    "Invite {user}" : "Invitar a {user}",
    "Invite all users and emails in this conversation" : "Invitar a todos los usuarios y correos electrónicos en esta conversación",
    "Meeting created" : "Reunión creada",
    "Upcoming meetings" : "Próximas reuniones",
    "Loading …" : "Cargando …",
    "No upcoming meetings" : "No hay próximas reuniones",
    "Schedule a meeting" : "Programar una reunión",
    "Meeting title" : "Título de la reunión",
    "From" : "De",
    "To" : "A",
    "Calendar" : "Calendario",
    "Attendees" : "Asistentes",
    "No other participants to send invitations to." : "No hay otros participantes a los cuales enviar invitaciones.",
    "Add attendees" : "Añadir asistentes",
    "Save" : "Guardar",
    "Search participants" : "Buscar participantes",
    "No results" : "Sin resultados",
    "Done" : "Listo",
    "Disable live transcription" : "Deshabilitar transcripción en vivo",
    "Disable live translation" : "Desactivar traducción en vivo",
    "Raise hand" : "Levantar la mano",
    "Raise hand (R)" : "Levantar mano (R)",
    "Lower hand" : "Bajar la mano",
    "Lower hand (R)" : "Bajar mano (R)",
    "Exit full screen (F)" : "Salir de pantalla completa (F)",
    "Full screen (F)" : "Pantalla completa (F)",
    "Speaker view" : "Vista de orador",
    "Grid view" : "Vista en cuadrícula",
    "Error when trying to load the available live transcription languages" : "Error al intentar cargar los lenguajes de transcripción disponibles",
    "Failed to enable live transcription" : "Fallo al habilitar la transcripción en vivo",
    "Recording consent is required" : "Es necesario el consentimiento de grabación",
    "This conversation is read-only" : "Esta conversación es de solo lectura",
    "Conversation not found or not joined" : "No se encuentra la conversación, o no se ha unido a ella",
    "Lobby is still active and you're not a moderator" : "La sala de espera sigue activa y Ud. no es un moderador",
    "Connection failed" : "La conexión ha fallado",
    "Reload" : "Recargar",
    "{nickName} raised their hand." : "{nickName} ha levantado la mano",
    "A participant raised their hand." : "Alguien ha levantado la mano.",
    "Collapse stripe" : "Colapsar franja",
    "Expand stripe" : "Expandir franja",
    "Previous page of videos" : "Página anterior de vídeos",
    "Next page of videos" : "Página siguiente de vídeos",
    "Connecting …" : "Conectando …",
    "Calling …" : "Llamando …",
    "Waiting for {user} to join the call" : "Esperando a que {user} se una a la llamada",
    "Waiting for others to join the call …" : "Esperando a otros a unirse a la llamada …",
    "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otros en la pestaña de participantes en la barra lateral",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Puede invitar a otras personas en la pestaña de participantes de la barra lateral o compartir este enlace para invitar a otras personas",
    "Share this link to invite others!" : "Comparte este enlace para invitar a otras personas.",
    "Copy link" : "Copiar enlace",
    "You are not allowed to enable audio" : "No está autorizado a activar el audio",
    "No audio. Click to select device" : "Sin audio. Haga click para seleccionar dispositivo",
    "Mute audio" : "Silenciar audio",
    "Mute audio (M)" : "Silenciar audio (M)",
    "Unmute audio" : "Activar audio",
    "Unmute audio (M)" : "Escuchar audio (M)",
    "None" : "Ninguno",
    "Select a microphone" : "Seleccione un micrófono",
    "Select a speaker" : "Seleccione un parlante",
    "Check devices" : "Comprobar dispositivos",
    "Access to camera was denied" : "Se ha denegado el acceso a la cámara",
    "Error while accessing camera: It is likely in use by another program" : "Error al acceder a la cámara: puede que la esté usando otro programa",
    "Error while accessing camera" : "Error al acceder a la cámara",
    "You have been muted by a moderator" : "Has sido silenciado por un moderador",
    "Hide presenter video" : "Ocultar video del presentador",
    "You are not allowed to enable video" : "No está autorizado a activar el vídeo",
    "No video. Click to select device" : "Sin video. Haga click para seleccionar dispositivo",
    "Disable video" : "Desactivar video",
    "Disable video (V)" : "Desactivar video (V)",
    "Enable video" : "Activar vídeo",
    "Enable video (V)" : "Activar video (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar video - Su conexión será brevemente interrumpida cuando se habilite el video por primera vez",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Activar video (V) - Su conexión será interrumpida un instante cuando se active el video por primera vez",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Active el vídeo. Su conexión será brevemente interrumpida cuando active el vídeo la primera vez",
    "Select a video device" : "Seleccione un dispositivo de video",
    "Show presenter" : "Mostrar presentador",
    "You" : "Tú",
    "Mute" : "Silenciar",
    "Muted" : "Silenciado",
    "Show screen" : "Mostrar pantalla",
    "Stop following" : "Dejar de seguir",
    "Connection could not be established …" : "No se pudo establecer la conexión …",
    "Connection was lost and could not be re-established …" : "Se ha perdido la conexión y no se pudo re-establecer …",
    "Connection could not be established. Trying again …" : "No se pudo establecer la conexión. Intentándolo de nuevo …",
    "Connection lost. Trying to reconnect …" : "Se ha perdido la conexión. Intentando reconectar …",
    "Connection problems …" : "Problemas de conexión …",
    "Collapse" : "Colapsar",
    "Expand" : "Expendir",
    "You need to be logged in to upload files" : "Necesita estar conectado para subir archivos",
    "Drop your files to upload" : "Arrastra tus archivos para subir",
    "Conversation messages" : "Mensajes de la conversación",
    "Scroll to bottom" : "Ir al final",
    "Post message" : "Publicar mensaje",
    "Federated conversation" : "Conversación federada",
    "Public conversation" : "Conversación pública",
    "Favorite" : "Favorito",
    "Banned users" : "Usuarios bloqueados",
    "Manage the list of banned users in this conversation." : "Gestionar la lista de usuarios bloqueados en esta conversación.",
    "Manage bans" : "Gestionar bloqueos",
    "No banned users" : "No hay usuarios bloqueados",
    "Banned by:" : "Bloqueado por:",
    "Date:" : "Fecha:",
    "Note:" : "Nota:",
    "Hide details" : "Ocultar detalles",
    "Show details" : "Mostrar detalles",
    "Unban" : "Desbloquear",
    "You can change the title and the description in {linkstart}Calendar ↗{linkend}." : "Puede cambiar el título y la descripción en {linkstart} Calendario ↗{linkend}.",
    "Error while updating conversation name" : "Error al actualizar el nombre de la conversación",
    "Error while updating conversation description" : "Se ha producido un error al actualizar la descripción",
    "Enter a name for this conversation" : "Ingrese un nombre para esta conversación",
    "Edit conversation name" : "Editar el nombre de la conversación",
    "Edit conversation description" : "Editar descripción de la conversación",
    "Enter a description for this conversation" : "Introduce una descripción para esta conversación",
    "Picture" : "Imagen",
    "The following bots can be enabled in this conversation. Reach out to your administration to get more bots installed on this server." : "Se pueden habilitar los siguientes bots en esta conversación. Contacte con su administrador para tener más bots instalados en este servidor.",
    "No bots are installed on this server. Reach out to your administration to get bots installed on this server." : "No hay bots instalados en este servidor. Contacte con su administrador para tener más bots instalados en este servidor.",
    "Disable" : "Deshabilitar",
    "Enable" : "Habilitar",
    "Breakout rooms" : "Salas de grupos",
    "Manage breakout rooms" : "Administrar salas de grupos",
    "Set up breakout rooms for this conversation" : "Configurar salas de grupos para esta conversación",
    "Please select a valid PNG or JPG file" : "Por favor seleccione un archivo PNG o JPG válido.",
    "Choose your conversation picture" : "Seleccione su imagen de la conversación",
    "Choose" : "Seleccione",
    "Error setting conversation picture" : "Error al establecer la imagen de la conversación",
    "Could not set the conversation picture: {error}" : "No fue posible establecer la imagen de la conversación: {error}",
    "Error cropping conversation picture" : "Error al recortar la imagen de la conversación",
    "Error removing conversation picture" : "Error al quitar la imagen de la conversación",
    "Set emoji as conversation picture" : "Establecer emoji como imagen de la conversación",
    "Set background color for conversation picture" : "Establecer el color de fondo para la imagen de la conversación",
    "Upload conversation picture" : "Subir imagen de la conversación",
    "Choose conversation picture from files" : "Seleccionar imagen de la conversación desde los archivos",
    "Remove conversation picture" : "Eliminar la imagen de la conversación",
    "The file must be a PNG or JPG" : "El archivo debe ser un PNG o JPG",
    "Set picture" : "Establecer imagen",
    "Default permissions modified for {conversationName}" : "Permisos por defecto modificados para {conversationName}",
    "Could not modify default permissions for {conversationName}" : "No se pudieron modificar los permisos por defecto para {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Edita los permisos por defecto de los participantes de esta conversación. Estos ajustes no afectan a los moderadores.",
    "Every time permissions are modified in this section, custom permissions previously assigned to individual participants will be lost." : "Cada vez que se modifiquen los permisos en esta sección, los permisos personalizados asignados previamente a participantes individuales serán perdidos.",
    "All permissions" : "Todos los permisos",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Los participantes tienen permisos para crear una llamada, unirse a una llamada, habilitar audio y vídeo, y compartir su pantalla.",
    "Restricted" : "Restringido",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Los participantes pueden unirse a llamadas, pero no pueden habilitar ni su audio ni su vídeo, ni compartir pantalla hasta que un moderador les otorgue estos permisos manualmente.",
    "Advanced permissions" : "Permisos avanzados",
    "Edit permissions" : "Editar permisos",
    "Conversation settings" : "Ajustes de la conversación",
    "Basic Info" : "Información Básica",
    "Personal" : "Personal",
    "Moderation" : "Moderación",
    "Setup overview" : "Resumen de configuración",
    "Live transcription" : "Transcripción en vivo",
    "Enable live transcription" : "Habilitar transcripción en vivo",
    "Breakout Rooms" : "Salas de grupos",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Zona de peligro",
    "Archive conversation" : "Archivar conversación",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Las conversaciones archivadas se ocultarán de la lista de conversaciones de forma predeterminada. Sin embargo, aparecerán cuando busque el nombre de la conversación o abra la lista de conversaciones archivadas.",
    "Do you really want to leave \"{displayName}\"?" : "¿De verdad quiere abandonar  \"{displayName}\"?",
    "You can archive this conversation instead." : "Puede archivar esta conversación en su lugar.",
    "Leave conversation" : "Abandonar conversación",
    "You need to promote a new moderator before you can leave the conversation" : "Debe escoger a un nuevo moderador antes de que pueda abandonar la conversación",
    "Delete conversation" : "Borrar conversación",
    "Do you really want to delete \"{displayName}\"?" : "¿Estás seguro de que quieres borrar \"{displayName}\"?",
    "Error while deleting conversation" : "Error al eliminar una conversación",
    "Delete all chat messages" : "Eliminar todos los mensajes del chat",
    "Do you really want to delete all messages in \"{displayName}\"?" : "¿Realmente desea eliminar todos los mensajes de \"{displayName}\"?",
    "Error while clearing chat history" : "Error al borrar el historial del chat",
    "Be careful, these actions cannot be undone." : "Tenga cuidado, estas acciones no se pueden deshacer.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Una vez que se abandona una conversación, para reincorporarse a una conversación cerrada se necesita una invitación. Puede volverse a unir a una conversación abierta en cualquier momento.",
    "Permanently delete this conversation." : "Eliminar permanentemente esta conversación.",
    "Delete chat messages" : "Eliminar los mensajes del chat",
    "Permanently delete all the messages in this conversation." : "Eliminar permanentemente todos los mensajes de esta conversación.",
    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
    "_%n day_::_%n days_" : ["%n día","%n días","%n días"],
    "_%n week_::_%n weeks_" : ["%n semana","%n semanas","%n semanas"],
    "Custom expiration time" : "Tiempo de expiración personalizado",
    "Message expiration disabled" : "Se deshabilitó la expiración de mensajes",
    "Message expiration set: {duration}" : "Se estableció la expiración de mensaje: {duration}",
    "Error when trying to set message expiration" : "Se encontró un error al intentar establecer la expiración de mensajes",
    "Message expiration" : "Expiración de mensajes",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Los mensajes de chat pueden expirarse luego de cierto tiempo. Nota: Los archivos compartidos en el chat no serán borrados para el propietario, pero no estarán compartidos en la conversación.",
    "Set message expiration" : "Establecer la expiración de los mensajes",
    "Current message expiration" : "Expiración de los mensajes actual",
    "Password copied to clipboard" : "Contraseña copiada al portapapeles",
    "Password could not be copied" : "La contraseña no se ha podido copiar",
    "Guest access" : "Acceso de invitado",
    "Breakout rooms are not allowed in public conversations." : "Las salas de grupos no están permitidas en conversaciones públicas.",
    "Allow guests to join this conversation via link" : "Permitir que los invitados se unan a través de un enlace",
    "Password protection" : "Protección por contraseña",
    "This conversation is password-protected. Guests need password to join" : "Esta conversación está protegida con contraseña. Los invitados necesitan una contraseña para unirse",
    "Password protection is needed for public conversations" : "La protección con contraseña es obligatoria para conversaciones públicas",
    "Set a password" : "Establecer una contraseña",
    "Change password" : "Cambiar contraseña",
    "Enter new password" : "Introduzca una nueva contraseña",
    "Save password" : "Guardar contraseña",
    "Copy password" : "Copiar contraseña",
    "Guests are allowed to join this conversation via link" : "Los invitados pueden unirse a esta conversación a través de un enlace",
    "Guests are not allowed to join this conversation" : "Los invitados no pueden unirse a esta conversación",
    "Resend invitations" : "Reenviar las invitaciones",
    "This conversation is open to both registered users and users created with the Guests app" : "Esta conversación está abierta a usuarios registrados y a usuarios creados con la app Guests",
    "This conversation is open to registered users" : "Esta conversación está abierta a usuarios registrados",
    "This conversation is limited to the current participants" : "Esta conversación está limitada a los participantes actuales",
    "You opened the conversation to both registered users and users created with the Guests app" : "Ha abierto la conversación tanto a participantes registrados como a usuarios creados con la app Guests",
    "Error occurred when opening or limiting the conversation" : "Se ha producido un error al abrir o limitar la conversación",
    "Open conversation to registered users, showing it in search results" : "Abrir la conversación a los usuarios registrados, mostrándola en los resultados de búsqueda",
    "Also open to users created with the Guests app" : "También abrir la misma a los usuarios creados con la app Guests",
    "Open conversation" : "Abrir conversación",
    "Set language spoken in calls" : "Establecer el lenguaje hablado en las llamadas",
    "Languages could not be loaded" : "Los lenguajes no pudieron ser cargados",
    "Loading languages …" : "Cargando lenguajes …",
    "Invalid language" : "Idioma inválido",
    "Default language (English)" : "Lenguaje predeterminado (Inglés)",
    "Default live transcription language set" : "Se ha establecido el lenguaje predeterminado para la transcripción en vivo",
    "Live transcription language set: {languageName}" : "Lenguaje de transcripción en vivo establecido: {languageName}",
    "Error when trying to set live transcription language" : "Error al intentar establecer el idioma predeterminado de transcripción en vivo",
    "Start time: {date}" : "Hora de inicio: {date}",
    "Start time has been updated" : "Se ha actualizado la hora de inicio",
    "Error occurred while updating start time" : "Se ha producido un error al actualizar la hora de inicio",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Habilitar la sala de espera causará que aquellos usuarios que no sean moderadores sean removidos de la llamada en curso.",
    "Enable lobby, restricting the conversation to moderators" : "Habilitar la sala de espera, restringiendo la conversación únicamente a los moderadores",
    "Meeting start time" : "Hora de inicio de la reunión",
    "Start time (optional)" : "Hora de inicio (opcional)",
    "Import email participants" : "Importar participantes por correo electrónico",
    "You can import a list of email participants from a CSV file." : "Puede importar una lista de participantes por correo electrónico desde un archivo CSV.",
    "Poll drafts" : "Borradores de encuestas",
    "Browse poll drafts" : "Explorar borradores de encuestas",
    "Error occurred when locking the conversation" : "Se ha producido un error al bloquear la conversación",
    "Error occurred when unlocking the conversation" : "Se ha producido un error al desbloquear la conversación",
    "Lock conversation" : "Bloquear conversación",
    "This will also terminate the ongoing call." : "Esto también terminará la llamada en curso.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Bloquear la conversación para impedir a cualquiera publicar mensajes o iniciar llamadas.",
    "Edit" : "Editar",
    "More information" : "Más información",
    "Delete" : "Eliminar",
    "Add new bridged channel to current conversation" : "Añadir un canal enlazado a la conversación actual",
    "unknown state" : "estado desconocido",
    "running" : "funcionando",
    "not running, check Matterbridge log" : "sin funcionamiento, comprueba el registro de Matterbridge",
    "not running" : "sin funcionar",
    "Bridge saved" : "Enlace guardado",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Puedes enlazar canales de varios sistemas de mensajería instantánea con Matterbridge.",
    "More info on Matterbridge" : "Más información sobre Matterbridge",
    "Messaging systems" : "Sistemas de mensajería",
    "Enable bridge" : "Habilitar enlace",
    "Show Matterbridge log" : "Ver registro de Matterbridge",
    "Log content" : "Contenido del registro",
    "Only moderators are allowed to mention @all" : "Solo los moderadores pueden mencionar a @all",
    "All participants are allowed to mention @all" : "Todos los participantes pueden mencionar a @all",
    "Participants are now allowed to mention @all." : "Los participantes ahora pueden mencionar a @all",
    "Mentioning @all has been limited to moderators." : "La mención a @all ha sido limitada a los moderadores.",
    "Allow participants to mention @all" : "Permitir a los participantes mencionar a todos con @all",
    "Mention permissions" : "Permisos de mención",
    "Notifications" : "Notificaciones",
    "Notify about calls in this conversation" : "Notificar llamadas en esta conversación",
    "Important conversation" : "Conversación importante",
    "\"Do not disturb\" user status is ignored for important conversations" : "El estado \"No molestar\" se ignorará para las conversaciones importantes",
    "Sensitive conversation" : "Conversación sensible",
    "Message preview will be disabled in conversation list and notifications" : "La vista previa de los mensajes será deshabilitada en la lista de conversaciones y en las notificaciones",
    "Recording consent is required for calls in this conversation" : "El consentimiento de grabación es obligatorio para llamadas en esta conversación",
    "Recording consent is not required for calls in this conversation" : "El consentimiento de grabación no es obligatorio para llamadas en esta conversación",
    "Recording consent requirement was updated" : "Los requisitos de consentimiento de grabación fueron actualizados",
    "Error occurred while updating recording consent" : "Error al actualizar los consentimientos de grabación",
    "Recording Consent" : "Consentimiento de grabación",
    "Recording consent cannot be changed once a call or breakout session has started." : "No se puede cambiar el consentimiento de grabación una vez que una llamada o sesión de salas de grupos ha comenzado",
    "Require recording consent before joining call in this conversation" : "Obtener consentimiento de grabación antes de unirse a llamadas en esta conversación",
    "Recording consent is required for all calls" : "El consentimiento de grabación es obligatorio para todas las llamadas",
    "SIP dial-in is now possible without PIN requirement" : "Ahora es posible la marcación SIP sin necesidad de PIN",
    "SIP dial-in is now enabled" : "Se ha habilitado la conexión telefónica SIP",
    "SIP dial-in is now disabled" : "Se ha deshabilitado la conexión telefónica SIP",
    "Error occurred when enabling SIP dial-in" : "Se ha producido un error al habilitar la conexión telefónica SIP",
    "Error occurred when disabling SIP dial-in" : "Se ha producido un error al deshabilitar la conexión telefónica SIP",
    "Phone and SIP dial-in" : "Conexión telefónica y marcado SIP ",
    "Enable phone and SIP dial-in" : "Habilitar conexión telefónica y marcado SIP",
    "Allow to dial-in without a PIN" : "Permitir la marcación sin PIN",
    "Ongoing" : "En curso",
    "{dayPrefix} {dateTime}" : "{dayPrefix}{dateTime}",
    "_%n person accepted_::_%n people accepted_" : ["%n persona aceptó","%n personas aceptaron","%n personas aceptaron"],
    "_%n person declined_::_%n people declined_" : ["%n persona rechazó","%n personas rechazaron","%n personas rechazaron"],
    "_and %n other attachment_::_and %n other attachments_" : ["y %n otro adjunto","y otros %n adjuntos","y otros %n adjuntos"],
    "With {displayName}" : "Con {displayName}",
    "In {conversation}" : "En {conversation}",
    "View attachment" : "Ver adjunto",
    "Join" : "Unirse",
    "View conversation" : "Ver conversación",
    "View event on Calendar" : "Ver evento en Calendar",
    "Error while creating the conversation" : "Ocurrió un error al crear la conversación",
    "Hello, {displayName}" : "Hola,{displayName}",
    "Start meeting now" : "Iniciar reunión ahora",
    "Give your meeting a title" : "Asigna un título a tu reunión",
    "Create and copy link" : "Crear y copiar enlace",
    "Create a new conversation" : "Crear una conversación nueva",
    "Join open conversations" : "Unirse a conversaciones abiertas",
    "Call a phone number" : "Llamar a un número de teléfono",
    "Scroll backward" : "Desplazarse hacia atrás",
    "Scroll forward" : "Desplazarse hacia adelante",
    "Schedule meetings" : "Programar reuniones",
    "You don't have any upcoming meetings" : "No tiene próximas reuniones",
    "Open calendar" : "Abrir calendario",
    "Unread mentions" : "Menciones sin leer",
    "Messages where you were mentioned will show up here. You can mention people by typing @ followed by their name" : "Los mensajes donde fue mencionado aparecerán aquí. Puede mencionar a las personas escribiendo @ seguido de su nombre",
    "Upcoming reminders" : "Próximos recordatorios",
    "Message reminders" : "Recordatorios de mensajes",
    "Set a reminder on a message to be notified" : "Establezca un recordatorio en un mensaje para ser notificado",
    "Start a group conversation" : "Iniciar una conversación grupal",
    "Create conversation" : "Crear conversación",
    "Enter your name" : "Escriba su nombre",
    "Submit name and join" : "Enviar nombre y unirse",
    "Do you already have an account?" : "¿Ya tiene una cuenta?",
    "Log in" : "Iniciar sesión",
    "Error while verifying uploaded file" : "Error al verificar el archivo cargado",
    "Uploaded file is verified" : "El archivo subido ha sido verificado",
    "Content format is comma-separated values (CSV):<br/>- Header line is required and must match <samp>\"name\",\"email\"</samp> or just <samp>\"email\"</samp><br/>- One entry per line (e.g. <samp>\"John Doe\",\"john@example.tld\"</samp>)" : "El formato del contenido está separado por comas (CSV):<br/>- Se requiere una línea de cabecera y debe coincidir con <samp>\"name\",\"email\"</samp> o solamente <samp>\"email\"</samp><br/>- Una entrada por línea (p.ej. <samp>\"John Doe\",\"john@example.tld\"</samp>)",
    "Participants added successfully" : "Se añadieron los participantes exitosamente",
    "Error while adding participants" : "Error al añadir participantes",
    "Import a file" : "Importar un archivo",
    "Browse" : "Explorar",
    "Verifying uploaded file …" : "Verificando el archivo importado …",
    "This might take a moment" : "Esto puede tomar un momento",
    "Send invitations" : "Enviar invitaciones",
    "_%n invalid email_::_%n invalid emails_" : ["%n correo inválido","%n correos inválidos","%n correos inválidos"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n correo ya importado o duplicado","%n correos ya importados o duplicados","%n correos ya importados o duplicados"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n invitación puede ser enviada","%n invitaciones pueden ser enviadas","%n invitaciones pueden ser enviadas"],
    "An error occurred while calling a phone number" : "Ha ocurrido un error al llamar a un número de teléfono",
    "Phone number could not be called: {error}" : "No se pudo llamar al número de teléfono: {error}",
    "Phone number could not be called" : "No se pudo llamar al número de teléfono",
    "Search participants or phone numbers" : "Buscar participantes o números de teléfono",
    "Creating the conversation …" : "Creando la conversación …",
    "Mark as read" : "Marcar como leído",
    "Mark as unread" : "Marcar como no leído",
    "Remove from favorites" : "Eliminar de favoritos",
    "Add to favorites" : "Añadir a favoritos",
    "Unarchive conversation" : "Desarchivar conversación",
    "Ignore \"Do not disturb\"" : "Ignorar el estado \"No molestar\"",
    "You need to promote a new moderator before you can leave the conversation." : "Necesitas elegir un nuevo moderador antes de que puedas abandonar la conversación",
    "Conversation actions" : "Acciones de conversación",
    "Notify about calls" : "Notificar sobre llamadas",
    "Hide message text" : "Esconder texto del mensaje",
    "Pending invitations" : "Invitaciones pendientes",
    "From {user} at {remoteServer}" : "De {usuario} en {remoteServer}",
    "Decline invitation" : "Declinar invitación",
    "Accept invitation" : "Aceptar invitación",
    "No pending invitations" : "No hay invitaciones pendientes",
    "Home" : "Inicio",
    "Unread" : "No leído",
    "Mentions" : "Menciones",
    "Meetings" : "Reuniones",
    "Alphabetically" : "Alfabético",
    "No followed threads" : "Sin hilos seguidos",
    "No matches found" : "No se han encontrado coincidencias",
    "No conversations found" : "No se han encontrado conversaciones",
    "You have no archived conversations." : "No tiene conversaciones archivadas.",
    "Subscribe to an existing thread or start your own." : "Suscríbase a un hilo existente o inicie uno propio.",
    "You have no unread mentions." : "No tiene menciones sin leer.",
    "You have no unread messages." : "No tiene mensajes sin leer.",
    "An error occurred while performing the search" : "Ha ocurrido un error mientras se realizaba la búsqueda",
    "Conversation list" : "Lista de conversaciones",
    "Filter conversations by" : "Filtrar conversaciones por",
    "Unread messages" : "Mensajes no leídos",
    "Meeting conversations" : "Conversaciones de las reuniones",
    "Clear filters" : "Limpiar filtros",
    "New personal note" : "Nueva nota personal",
    "Back to conversations" : "Volver a conversaciones",
    "Archived conversations" : "Conversaciones archivadas",
    "Threads" : "Hilos",
    "Clear filter" : "Borrar filtro",
    "Show more threads" : "Mostrar más hilos",
    "App settings" : "Configuración de la app",
    "Users" : "Usuarios",
    "Groups" : "Grupos",
    "Teams" : "Equipos",
    "Federated users" : "Usuarios federados",
    "New private conversation" : "Nueva conversación privada",
    "Other sources" : "Otras fuentes",
    "Open conversations" : "Abrir conversaciones",
    "No search results" : "No hay resultados de búsqueda",
    "Users, groups and teams" : "Usuarios, grupos y equipos",
    "Users and groups" : "Usuarios y grupos",
    "Users and teams" : "Usuarios y equipos",
    "Groups and teams" : "Grupos y equipos",
    "New group conversation" : "Nueva conversación grupal",
    "The meeting will start soon" : "La reunión comenzará en breve",
    "This meeting is scheduled for {startTime}" : "Esta reunión está programada para {startTime}",
    "You are currently waiting in the lobby" : "Ahora estás esperando en la sala de espera.",
    "Select microphone" : "Selecciona micrófono",
    "No microphone available" : "No hay micrófonos disponibles",
    "Select speaker" : "Seleccionar orador",
    "No speaker available" : "No hay oradores disponibles",
    "Select camera" : "Selecciona cámara",
    "No camera available" : "No hay cámaras disponibles",
    "Select a device" : "Seleccione un dispositivo",
    "Playing …" : "Reproduciendo …",
    "Test speakers" : "Probar parlantes",
    "Test" : "Prueba",
    "Devices" : "Dispositivos",
    "Backgrounds" : "Fondos",
    "No audio" : "Sin sonido",
    "No camera" : "No hay cámara",
    "Display video as you will see it (mirrored)" : "Mostrar vídeo como Ud. lo verá (espejo)",
    "Display video as others will see it" : "Mostrar vídeo como lo verá el resto",
    "Calls are not supported in your browser" : "Tu navegador no admite llamadas",
    "Access to microphone is only possible with HTTPS" : "El acceso al micrófono solo es posible con HTTPS",
    "Access to microphone was denied" : "Se ha denegado el acceso al micrófono",
    "Error while accessing microphone" : "Error al acceder al micrófono",
    "Access to camera is only possible with HTTPS" : "El acceso a la cámara solo es posible con HTTPS",
    "The call is being recorded." : "La llamada está siendo grabada.",
    "The call might be recorded." : "La llamada podría ser grabada.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "La grabación podría incluir su voz, vídeo de su cámara y la pantalla compartida. Es necesario que dé su consentimiento antes de unirse a la llamada.",
    "Give consent to the recording of this call" : "Dar mi consentimiento a la grabación de esta llamada",
    "Show more info" : "Mostrar más información",
    "Audio is not available" : "El audio no está disponible",
    "Video is not available" : "El vídeo no está disponible",
    "Start recording immediately with the call" : "Iniciar la grabación inmediatamente con la llamada",
    "Notify all participants about this call" : "Notificar a todos los participantes de esta llamada",
    "Apply settings" : "Aplicar ajustes",
    "Select virtual office background" : "Seleccione el fondo virtual de oficina",
    "Select virtual home background" : "Seleccione el fondo virtual de casa",
    "Select virtual abstract background" : "Seleccione el fondo virtual abstracto",
    "Select virtual beach background" : "Seleccione el fondo virtual de playa",
    "Select virtual park background" : "Seleccione el fondo virtual de parque",
    "Select virtual theater background" : "Seleccione el fondo virtual de teatro",
    "Select virtual library background" : "Seleccione el fondo virtual de biblioteca",
    "Select virtual space station background" : "Selecicone el fondo virtual de estación espacial",
    "Error while uploading the file" : "Ocurrió un error mientras se subía el archivo",
    "Select a file" : "Selecciona un archivo",
    "Invalid path selected" : "Ruta de archivo seleccionada no válida.",
    "Select virtual background from file {fileName}" : "Seleccione el fondo virtual desde el archivo {fileName}",
    "Blur" : "Desenfoque",
    "Upload" : "Subir",
    "Files" : "Archivos",
    "(editing)" : "(editando)",
    "(edited)" : "(editado)",
    "The message has expired or has been deleted" : "El mensaje caducó o ha sido eliminado",
    "Cancel quote" : "Cancelar cita",
    "24 hours" : "24 horas",
    "7 days" : "7 días",
    "Until unpin" : "Hasta desfijar",
    "Clear reminder – {timeLocale}" : "Quitar recordatorio – {timeLocale}",
    "Edited by {actor}" : "Editado por {actor}",
    "Message text copied to clipboard" : "Texto del mensaje copiado al portapapeles",
    "Message text could not be copied" : "El texto del mensaje no pudo ser copiado",
    "Message forwarded to \"Note to self\"" : "El mensaje se reenvió a \"Nota personal\"",
    "Error while forwarding message to \"Note to self\"" : "Error al reenviar el mensaje a \"Nota personal\"",
    "A reminder was successfully removed" : "Se ha eliminado correctamente un recordatorio",
    "Error occurred when removing a reminder" : "Ha habido un error al borrar un recordatorio",
    "A reminder was successfully set at {datetime}" : "Se ha configurado un recordatorio correctamente a las {datetime}",
    "Error occurred when creating a reminder" : "Ocurrió un error al crear un recordatorio",
    "Add a reaction to this message" : "Añade una reacción a este mensaje",
    "Reply" : "Responder",
    "More actions" : "Más acciones",
    "Set reminder" : "Establecer recordatorio",
    "Pin message" : "Fijar mensaje",
    "Unpin message" : "Desfijar mensaje",
    "Reply privately" : "Responder en privado",
    "Edit message" : "Editar mensaje",
    "Copy message" : "Copiar mensaje",
    "Copy message link" : "Copiar link del mensaje",
    "Go to file" : "Ir al archivo",
    "Download file" : "Descargar archivo",
    "Go to thread" : "Ir al hilo",
    "Edit thread details" : "Editar detalles del hilo",
    "Forward message" : "Reenviar mensaje",
    "Translate" : "Traducir",
    "Set custom reminder" : "Establecer recordatorio personalizado",
    "Close reactions menu" : "Cerrar menú de reacciones",
    "React with {emoji}" : "Reaccionar con {emoji}",
    "React with another emoji" : "Reaccionar con otro emoji",
    "Choose a conversation to forward the selected message." : "Elija una conversación para reenviar el mensaje seleccionado.",
    "Error while forwarding message" : "Error al reenviar el mensaje",
    "The message has been forwarded to {selectedConversationName}" : "El mensaje ha sido reenviado a {selectedConversationName}",
    "Dismiss" : "Descartar",
    "Go to conversation" : "Ir a la conversación",
    "Detect language" : "Detectar idioma",
    "The message could not be translated" : "El mensaje no pudo ser traducido",
    "Translation copied to clipboard" : "La traducción se copió al portapapeles",
    "Translation could not be copied" : "La traducción no pudo ser copiada",
    "Translate message" : "Traducir mensaje",
    "Source language to translate from" : "Lenguaje fuente desde el cual traducir",
    "Translate from" : "Traducir desde",
    "Target language to translate into" : "Lenguaje objetivo al que se hará la traducción",
    "Translate to" : "Traducir a",
    "Translating" : "Traduciendo",
    "Copy translated text" : "Copiar texto traducido",
    "Send now" : "Enviar ahora",
    "Message read by everyone who shares their reading status" : "Mensaje leído por todos los que comparten el estado de lectura",
    "Message sent" : "Mensaje enviado",
    "Sent without notification" : "Enviado sin notificación",
    "Deleting message" : "Eliminando mensaje",
    "Message deleted successfully, but a bot or Matterbridge is configured and the message might already be distributed to other services" : "Mensaje eliminado correctamente, pero un robot o Matterbridge está configurado y este mensaje puede haber sido distribuido a otros servicios.",
    "Message deleted successfully" : "Mensaje eliminado con éxito",
    "Message could not be deleted because it is too old" : "El mensaje no se ha podido eliminar porque es demasiado antiguo",
    "Only normal chat messages can be deleted" : "Solo se pueden eliminar mensaje normales del chat",
    "An error occurred while deleting the message" : "Ha ocurrido un error al eliminar el mensaje",
    "Pinned" : "Fijado",
    "Your browser does not support playing audio files" : "Su navegador no admite la reproducción de archivos de audio",
    "Contact" : "Contacto",
    "{stack} in {board}" : "{stack} en {board}",
    "Deck Card" : "Tarjeta Deck",
    "Remove {fileName}" : "Borrar {fileName}",
    "Open this location in OpenStreetMap" : "Abrir esta ubicación en OpenStreetMap",
    "_%n reply_::_%n replies_" : ["%n respuesta","%n respuestas","%n respuestas"],
    "Sending message" : "Enviando mensaje",
    "Failed to send the message. Click to try again" : "No se pudo enviar el mensaje. Haga clic para reintentar",
    "Not enough free space to upload file" : "No hay espacio libre suficiente para subir el archivo",
    "You cannot send messages to this conversation at the moment" : "No puedes enviar mensajes a esta conversación en este momento",
    "Could not update the message" : "No se pudo actualizar el mensaje",
    "You voted" : "Has votado",
    "_Poll draft • %n option_::_Poll draft • %n options_" : ["Borrador de encuesta • %n opción","Borrador de encuesta • %n opciones","Borrador de encuesta • %n opciones"],
    "_%n vote_::_%n votes_" : ["%n voto","%n votos","%n votos"],
    "Edit poll draft" : "Editar borrador de encuesta",
    "Delete poll draft" : "Eliminar borrador de encuesta",
    "Open poll" : "Abrir encuesta",
    "See results" : "Mostrar resultados",
    "Reactions" : "Reacciones",
    "No permission to post reactions in this conversation" : "No está permitido publicar reacciones en esta conversación",
    "and {participant}" : "y {participant}",
    "_and %n other participant_::_and %n other participants_" : ["y %n otro participante","y %n otros participantes","y %n otros participantes"],
    "Show all reactions" : "Mostrar todas las reacciones",
    "Add more reactions" : "Añadir más reacciones",
    "Show or collapse system messages" : "Expandir o contraer mensajes del sistema",
    "No messages" : "No hay mensajes",
    "All messages have expired or have been deleted." : "Todos los mensajes han expirado o han sido eliminados.",
    "{author} (pinned by you)" : "{author} (fijado por ti)",
    "Unpin" : "No fijar",
    "Cancel search" : "Cancelar búsqueda",
    "Add a phone number" : "Añadir un número de teléfono",
    "Error: A password is required to create the conversation." : "Error: La contraseña es necesaria para crear la conversación.",
    "All set, the conversation \"{conversationName}\" was created." : "Todo listo, la conversación \"{conversationName}\" fue creada.",
    "Create a new group conversation" : "Crear nueva conversación en grupo",
    "Add participants" : "Añadir participantes",
    "Maximum length exceeded ({maxlength} characters)" : "Tamaño máximo excedido ({maxlength} caracteres)",
    "Conversation visibility" : "Visibilidad de la conversación",
    "Allow guests to join via link" : "Permitir que los invitados se unan a través de un enlace",
    "Enter password" : "Introduzca la contraseña",
    "This conversation has been locked" : "Se ha bloqueado esta conversación",
    "No permission to post messages in this conversation" : "No tienes permiso para publicar mensajes en esta conversación",
    "Joining conversation …" : "Uniéndose a la conversación...",
    "Write a message without notification" : "Escribir un mensaje sin notificación",
    "Create a thread silently" : "Crear un hilo de manera silenciosa",
    "Create a thread" : "Crear un hilo",
    "Send message silently" : "Enviar mensaje en forma silenciosa",
    "Send message" : "Enviar mensaje",
    "Send without notification" : "Enviar sin notificación",
    "The participant will not be notified about new messages" : "El participante no será notificado de nuevos mensajes",
    "Participants will not be notified about new messages" : "Los participantes no serán notificados de nuevos mensajes",
    "Thread title is required" : "Se requiere un título para el hilo",
    "Message text is required" : "El texto del mensaje es requerido",
    "The message could not be edited" : "El mensaje no pudo ser editado",
    "File to share" : "Archivo que compartir",
    "File upload is not available in this conversation" : "La subida de archivos no está disponible en esta conversación",
    "Add emoji" : "Añadir emoji",
    "Adding a mention will only notify users who did not read the message." : "Añadir una mención solo notificará a los usuarios que no han leído el mensaje.",
    "Thread title" : "Título del hilo",
    "Send later" : "Enviar más tarde",
    "Cancel editing" : "Cancelar edición",
    "Schedule message" : "Programar mensaje",
    "{user} is out of office and might not respond." : "{user} está fuera de la oficina y es posible que no responda",
    "Absence period: {startDate} - {endDate}" : "Período de ausencia: {startDate} - {endDate}",
    "Replacement:" : "Reemplazo:",
    "Share from {nextcloud}" : "Compartir desde {nextcloud}",
    "Share from Files" : "Compartir desde Archivos",
    "Share files to the conversation" : "Compartir archivos en la conversación",
    "Upload from device" : "Subir desde dispositivo",
    "Create new poll" : "Crear nueva votación",
    "Smart picker" : "Selector inteligente",
    "Record voice message" : "Grabar mensaje de voz",
    "End recording and send" : "Finalizar grabación y enviar",
    "Dismiss recording" : "Descartar grabación",
    "Access to the microphone was denied" : "El acceso al micrófono fue denegado",
    "Microphone either not available or disabled in settings" : "El micrófono no está disponible o está desactivado en los ajustes",
    "Error while recording audio" : "Error al grabar el audio",
    "Generating summary of unread messages …" : "Generando resumen de mensajes no leídos …",
    "Summary is AI generated and might contain mistakes" : "El resumen se genera mediante IA y puede contener errores",
    "Error occurred during a summary generation" : "Ha ocurrido un error al generar el resumen",
    "New file" : "Nuevo archivo",
    "Blank" : "Vacío",
    "Error while creating file" : "Ha ocurrido un error al crear el archivo",
    "Create and share a new file" : "Crear y compartir un archivo nuevo",
    "Name of the new file" : "Nombre del archivo nuevo",
    "Create file" : "Crear archivo",
    "Someone is typing …" : "Alguien está escribiendo …",
    "{user1} is typing …" : "{user1} está escribiendo …",
    "{user1} and {user2} are typing …" : "{user1} y {user2} están escribiendo …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} y {user3} están escribiendo …",
    "_{user1}, {user2}, {user3} and %n other are typing …_::_{user1}, {user2}, {user3} and %n others are typing …_" : ["{user1}, {user2}, {user3} y %n otro están escribiendo …","{user1}, {user2}, {user3} y %n otros están escribiendo …","{user1}, {user2}, {user3} y %n otros están escribiendo …"],
    "Add more files" : "Añadir más archivos",
    "Send" : "Enviar",
    "In this conversation <strong>{user}</strong> can:" : "En esta conversación <strong>{user}</strong> puede:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Editar permisos por defecto para los participantes en <strong>{conversationName}</strong>",
    "Start a call" : "Iniciar una llamada",
    "Skip the lobby" : "Saltarse la sala de espera",
    "Can post messages and reactions" : "Puede publicar mensajes y reacciones",
    "Enable the microphone" : "Habilitar el micrófono",
    "Enable the camera" : "Habilitar la cámara",
    "Share the screen" : "Compartir la pantalla",
    "Update permissions" : "Actualizar permisos",
    "Updating permissions" : "Actualizando permisos",
    "No poll drafts" : "No hay borradores de encuestas",
    "There is no poll drafts yet saved for this conversation" : "No hay borradores de encuestas guardados todavía para esta conversación",
    "Create poll in {name}" : "Crear encuesta en {name}",
    "Create poll" : "Crear votación",
    "Error while importing poll" : "Error al importar encuesta",
    "Question" : "Pregunta",
    "Ask a question" : "Hacer una pregunta",
    "Import draft from file" : "Importar un borrador desde un archivo",
    "Answers" : "Respuestas",
    "Answer {option}" : "Respuesta {option}",
    "Delete poll option" : "Borrar opción de la encuesta",
    "Add answer" : "Añadir respuesta",
    "Settings" : "Ajustes",
    "Anonymous poll" : "Encuesta anónima",
    "Multiple answers" : "Múltiples respuestas",
    "Save as draft" : "Guardar como borrador",
    "Export draft to file" : "Exportar borrador a archivo",
    "You voted for this option" : "Ud. Votó por esta opción",
    "End poll" : "Cerrar la encuesta",
    "Change your vote" : "Cambiar su voto",
    "Results" : "Resultados",
    "Voted participants" : "Participantes votados",
    "Send a message to \"{roomName}\"" : "Enviar mensaje a \"{roomName}\"",
    "Hide list of participants" : "Ocultar lista de participantes",
    "Show list of participants" : "Mostrar lista de participantes",
    "Assistance requested in {roomName}" : "Se solicitó asistencia en {roomName}",
    "The message was sent to \"{roomName}\"" : "El mensaje fue enviado a \"{roomName}\"",
    "Dismiss request for assistance" : "Descartar solicitud de asistencia",
    "Send message to room" : "Enviar mensaje a sala",
    "Back to main room" : "Volver a la sala principal",
    "Back to your room" : "Volver a su sala",
    "Message all rooms" : "Enviar un mensaje a todas las salas",
    "Start session" : "Iniciar la sesión",
    "Start a call before you start a breakout room session" : "Inicie una llamada antes de iniciar una sesión de salas de grupos",
    "Stop session" : "Detener la sesión",
    "The message was sent to all breakout rooms" : "El mensaje fue enviado a todas las salas de grupos",
    "Send a message to all breakout rooms" : "Enviar mensaje a todas las salas de grupos",
    "Breakout rooms are not started" : "No se han iniciado las salas de grupos",
    "Calls without High-performance backend can cause connectivity issues and high load on devices. {linkstart}Learn more{linkend}" : "Las llamadas sin el backend de alto rendimiento pueden ocasionar problemas de conectividad y un alto nivel de trabajo en los dispositivos. {linkstart}Más información{linkend} ",
    "Talk setup incomplete" : "La configuración de Talk no está completa",
    "Disable lobby" : "Desactivar sala de espera",
    "Settings for participant \"{user}\"" : "Ajustes para participante «{user}»",
    "Participant \"{user}\"" : "Participante «{user}»",
    "moderator" : "moderador",
    "bot" : "bot",
    "guest" : "invitado",
    "Ringing …" : "Sonando …",
    "Call rejected" : "Llamada rechazada",
    "{time} talking …" : "{time} conversando …",
    "{time} talking time" : "{time} tiempo de conversación",
    "Raised their hand" : "Levantaron la mano",
    "Joined with video" : "Participa con vídeo",
    "Joined via phone" : "Participa por teléfono",
    "Joined with audio" : "Participa con audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "El texto debe ser menor o igual a {maxLength} caracteres. Su texto actual tiene {charactersCount} caracteres.",
    "Remove group and members" : "Eliminar grupo y miembros",
    "Remove team and members" : "Eliminar equipo y miembros",
    "Remove participant" : "Eliminar participante",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "¿Realmente desea eliminar el grupo \"{displayName}\" y a todos sus miembros de esta conversación?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "¿Realmente desea eliminar el equipo \"{displayName}\" y a todos sus miembros de esta conversación?",
    "Do you really want to remove {displayName} from this conversation?" : "¿Realmente desea eliminar a {displayName} de esta conversación?",
    "Notification was sent to {displayName}" : "La notificación fue enviada a {displayName}",
    "Could not send notification to {displayName}" : "No se ha podido enviar la notificación a {displayName}",
    "Permissions granted to {displayName}" : "Se han otorgado permisos a {displayName}",
    "Could not modify permissions for {displayName}" : "No se ha podido modificar los permisos para {displayName}",
    "Permissions removed for {displayName}" : "Permisos borrados para {displayName}",
    "Permissions set to default for {displayName}" : "Se establecieron los permisos predeterminados para {displayName}",
    "Phone number could not be hung up" : "El número de teléfono no se pudo colgar",
    "Phone number could not be put on hold" : "El número de teléfono no se pudo poner en espera",
    "Phone number could not be muted" : "No se pudo silenciar el número de teléfono",
    "Phone number could not be unmuted" : "No se pudo de-silenciar el número de teléfono",
    "DTMF message could not be sent" : "No se pudo enviar el mensaje DTMF",
    "Phone number copied to clipboard" : "Número de teléfono copiado al portapapeles",
    "Phone number could not be copied" : "No se pudo copiar el número de teléfono",
    "in the lobby" : "en la sala de espera",
    "Dial out phone" : "Teléfono para llamadas salientes",
    "Hang up phone" : "Colgar el teléfono",
    "Move back to lobby" : "Regresar a la sala de espera",
    "Move to conversation" : "Mover a la conversación",
    "Dial-in PIN" : "PIN de llamada",
    "Demote from moderator" : "Degradar de moderador",
    "Promote to moderator" : "Elevar a moderador",
    "Resend invitation" : "Reenviar invitación",
    "Send call notification" : "Enviar notificación de llamada",
    "Dial out phone number" : "Número de teléfono de llamadas salientes",
    "Resume call for phone number" : "Continuar llamada a número de teléfono",
    "Put phone number on hold" : "Poner número de teléfono en espera",
    "Unmute phone number" : "De-silenciar número de teléfono",
    "Mute phone number" : "Silenciar número de teléfono",
    "Copy phone number" : "Copia número de teléfono",
    "Reset custom permissions" : "Restaurar permisos personalizados",
    "Grant all permissions" : "Otorgar todos los permisos",
    "Remove all permissions" : "Revocar todos los permisos",
    "Also ban from this conversation" : "También bloquear de esta conversación",
    "Internal note (reason to ban)" : "Nota interna (razón para el bloqueo)",
    "Remove" : "Quitar",
    "Permissions modified for {displayName}" : "Permisos modificados para {displayName}",
    "Add users, groups or teams" : "Añadir usuarios, grupos o equipos",
    "Add users or groups" : "Añadir usuarios o grupos",
    "Add users or teams" : "Añadir usuarios o equipos",
    "Add users" : "Añadir usuarios",
    "Add groups or teams" : "Añadir grupos o equipos",
    "Add groups" : "Añadir grupos",
    "Add teams" : "Añadir equipos",
    "Add other sources" : "Añade otros orígenes",
    "Add emails" : "Añade correos electrónicos",
    "Integrations" : "Integraciones",
    "Add federated users" : "Añadir usuarios federados",
    "Searching …" : "Buscando  …",
    "Search for more users" : "Buscar más usuarios",
    "You can search or add participants via name, email, or Federated Cloud ID" : "Puedes buscar o añadir participantes por nombre, correo o ID de nube federada",
    "Search or add participants" : "Buscar o añadir participantes",
    "Invitation was sent to {actorId}" : "Se ha enviado la invitación a {actorId}.",
    "An error occurred while adding the participants" : "Se ha producido un error al añadir los participantes",
    "A new group conversation with selected participant will be created" : "Se creará una nueva conversación grupal con el participante seleccionado",
    "Participants" : "Participantes",
    "Participants ({count})" : "Participantes ({count})",
    "Open chat" : "Abrir chat",
    "You have new unread messages in the chat." : "Tiene nuevos mensajes sin leer en el chat.",
    "You have been mentioned in the chat." : "Se le ha mencionado en el chat.",
    "Search messages" : "Buscar mensajes",
    "Chat" : "Chat",
    "Details" : "Detalles",
    "Shared items" : "Elementos compartidos",
    "Search in {name}" : "Buscar en {name}",
    "Threads in {name}" : "Hilos en {name}",
    "{actor} in {conversation}" : "{actor} en {conversation}",
    "Search messages …" : "Buscar mensajes …",
    "Search options" : "Opciones de búsqueda",
    "From User" : "Del usuario",
    "Since" : "Desde",
    "Until" : "Hasta",
    "No results found" : "No se encontraron resultados",
    "Load more results" : "Cargar más resultados",
    "Recent threads" : "Hilos recientes",
    "Projects" : "Proyectos",
    "No shared items" : "No hay elementos compartidos",
    "Thread notifications" : "Notificaciones para hilos",
    "Thread actions" : "Acciones del hilo",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Enlace a una conversación",
    "No open conversations found" : "No se encontraron conversaciones abiertas",
    "Either there are no open conversations or you joined all of them." : "O bien no existen conversaciones abiertas, o, se unió a todas.",
    "Check spelling or use complete words." : "Chequee la ortografía o utilice palabras completas.",
    "Search conversations or users" : "Buscar conversaciones o usuarios",
    "Select conversation" : "Selecciona conversación",
    "Number length is not valid" : "La longitud del número no es válida",
    "Region code is not valid" : "El código de región no es válido",
    "Number length is too short" : "El número es demasiado corto",
    "Number length is too long" : "El número es demasiado largo",
    "Number is not valid" : "El número no es válido",
    "Phone numbers" : "Números de teléfono",
    "Display name: {name}" : "Nombre mostrado: {name}",
    "Edit display name" : "Editar nombre mostrado",
    "Display name (required)" : "Nombre a mostrar (requerido)",
    "Save name" : "Guardar nombre",
    "Error while setting personal setting" : "Error al guardar sus ajustes personales",
    "Error while saving sounds setting" : "Error al guardar la configuración de sonidos",
    "Play sounds when participants join or leave a call" : "Reproducir sonidos cuando los participantes se unen o abandonan una llamada",
    "Notification settings" : "Configuraciones de notificación",
    "Default language" : "Idioma predeterminado",
    "Select location for attachments" : "Seleccionar ubicación para los adjuntos",
    "Error while setting attachment folder" : "Error al fijar la carpeta para los archivos adjuntos",
    "Error while setting read status privacy" : "Error al ajustar la privacidad de la confirmación",
    "Error while setting typing status privacy" : "Error al ajustar la privacidad del estado de escritura",
    "Error while setting default media state" : "Error al guardar el estado predeterminado de sus dispositivos",
    "Privacy" : "Privacidad",
    "Attachments folder" : "Carpeta de adjuntos",
    "Toggle full screen" : "Cambiar a pantalla completa",
    "Search" : "Buscar",
    "Focus the chat input" : "Foco en la entrada del chat",
    "Unfocus the chat input to use shortcuts" : "Quitar el foco de la entrada del chat para usar atajos",
    "Edit your last message" : "Editar su último mensaje",
    "Shortcuts while in a call" : "Atajos durante una llamada",
    "Camera on and off" : "Encendido y apagado de la cámara",
    "Microphone on and off" : "Micrófono encendido y apagado",
    "Raise or lower hand" : "Levantar o bajar la mano",
    "Push to talk or push to mute" : "Pulsar para hablar o para silenciar",
    "Zoom-in / zoom-out a screen share" : "Acercar / Alejar una pantalla compartida",
    "Mouse wheel" : "Rueda del ratón",
    "Start call silently" : "Iniciar llamada en silencio",
    "Start call" : "Comenzar llamada",
    "End call" : "Finalizar llamada",
    "This call has just ended" : "Esta llamada acaba de finalizar",
    "You will be able to join the call only after a moderator starts it." : "Podrás unirte a la llamada cuando la inicie un moderador.",
    "End call for everyone" : "Finalizar llamada para todos",
    "Starting the recording" : "Empezar la grabación",
    "Recording" : "Grabando",
    "The call has been running for one hour." : "La llamada ha estado activa por una hora.",
    "Cancel recording start" : "Cancelar el inicio de la grabación",
    "Stop recording" : "Detener grabación",
    "Send a reaction" : "Enviar una reacción",
    "React with {reaction}" : "Reaccionar con {reaction}",
    "All tasks done!" : "¡Todas las tareas han sido completadas!",
    "_{done} of %n task_::_{done} of %n tasks_" : ["{done} de %n tarea","{done} de %n tareas","{done} de %n tareas"],
    "Add participants to this call" : "Añadir participantes a esta llamada",
    "_%n participant in call_::_%n participants in call_" : ["%n participante en la llamada","%n participantes en la llamada","%n participantes en la llamada"],
    "Scheduled messages" : "Mensajes programados",
    "You are not allowed to enable screensharing" : "No está autorizado a activar el uso compartido de la pantalla",
    "No screensharing" : "Sin compartición de pantalla",
    "Screensharing options" : "Opciones de compartir pantalla",
    "Enable screensharing" : "Activar compartir pantalla",
    "Bad sent video and screen quality." : "Mala calidad de vídeo y pantalla compartida.",
    "Bad sent screen quality." : "Mala calidad de pantalla compartida.",
    "Bad sent video quality." : "Mala calidad de vídeo.",
    "Bad sent audio, video and screen quality." : "Mala calidad de audio, vídeo y pantalla compartida.",
    "Bad sent audio and screen quality." : "Mala calidad de audio y pantalla compartida.",
    "Bad sent audio and video quality." : "Mala calidad de audio y vídeo.",
    "Bad sent audio quality." : "Mala calidad de audio.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Su conexión a internet o su ordenador están saturados y puede que otros participantes no vean su pantalla. Para mejorar la situación, intente desactivar el desenfoque del fondo o su vídeo mientras esté compartiendo su pantalla.",
    "Disable background blur" : "Deshabilitar el desenfoque del fondo",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Su conexión a internet o su ordenador están saturados y puede que otros participantes no vean su pantalla. Para mejorar la situación, intente desactivar su vídeo mientras esté compartiendo su pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Tu conexión a internet o tu ordenador tienen demasiada carga y quizás algunos participantes no puedan ver tu pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Tu conexión de internet o tu ordenador tienen demasiada carga y quizás algunos participantes no puedan verte.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Su conexión a internet o su ordenador están saturados y quizás otros participantes no puedan entenderle o verle. Para mejorar la situación, intente desactivar el desenfoque del fondo o su vídeo mientras esté compartiendo su pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Tu conexión a internet o tu ordenador tienen demasiada carga y quizás algunos participantes no puedan oírte ni verte. Para mejorar la situación, prueba a desactivar el vídeo mientras compartas tu pantalla.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Su conexión a internet o su ordenador están saturados y quizás otros participantes no puedan entenderle y verle. Para mejorar esta situación, intente desactivar el desenfoque del fondo o su vídeo mientras esté compartiendo su pantalla.",
    "Disable screenshare" : "Deshabilitar compartir pantalla",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Su conexión a internet o su ordenador están saturados y quizás otros participantes no puedan entenderle o verle. Para mejorar la situación, intente desactivar el desenfoque del fondo o su vídeo.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Tu conexión a internet o tu ordenador tienen demasiada carga y quizás algunos participantes no puedan oírte ni verte. Para mejorar la situación, prueba a desactivar tu cámara.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Tu conexión a internet o tu ordenador tienen demasiada carga y quizás algunos participantes no puedan oírte.",
    "Screen sharing is not supported by your browser." : "Tu navegador no admite compartir pantalla.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página sea cargada a través de HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página sea cargada a través de HTTPS.",
    "An error occurred while starting screensharing." : "Ocurrió un error al inciar el compartir pantalla",
    "Select virtual background" : "Seleccione fondo virtual",
    "Show your screen" : "Muestre su pantalla",
    "Stop screensharing" : "Detenga el compartir pantalla",
    "Mute others" : "Silenciar a los demás",
    "Start recording" : "Empezar a grabar",
    "Set up breakout rooms" : "Configurar salas de grupos",
    "Download attendance list" : "Descargar lista de asistentes",
    "Open Calendar" : "Abrir Calendario",
    "Remove participant {name}" : "Quitar participante {name}",
    "Would you like to delete this conversation?" : "¿Desea eliminar esta conversación?",
    "Are you sure you want to delete this conversation?" : "¿Está seguro que quiere eliminar esta conversación?",
    "Delete now" : "Eliminar ahora",
    "Keep" : "Conservar",
    "Open dialpad" : "Abrir marcador",
    "Select a region" : "Seleccione una región",
    "Local time: {time}" : "Hora local: {time}",
    "Search …" : "Buscar …",
    "Message without mention" : "Mensaje sin mencionar",
    "Mention myself" : "Mencionarme a mí mismo",
    "Mention everyone" : "Mencionar a todos",
    "Select a conversation" : "Seleccione una conversación",
    "Select a mode" : "Seleccione un modo",
    "You do not have permissions to access this conversation." : "No tiene permiso para acceder a esta conversación.",
    "Join a different conversation or start a new one." : "Únase a otra conversación o inicie una nueva.",
    "The conversation does not exist" : "La conversación no existe",
    "Join a conversation or start a new one!" : "¡Únete a una conversación o inicia una nueva!",
    "Duplicate session" : "Sesión duplicada",
    "Creating and joining a conversation with \"{userid}\"" : "Creando y uniéndose a una conversación con \"{userid}\"",
    "Join a conversation or start a new one" : "Únete a una conversación o empieza una nueva",
    "Error while joining the conversation" : "Error mientras se unía a la conversación",
    "Nextcloud URL" : "URL de Nextcloud",
    "Nextcloud user" : "Usuario de Nextcloud",
    "User password" : "Contraseña de usuario",
    "Talk conversation" : "Conversación de Talk",
    "Skip TLS verification" : "Omitir verificación TLS",
    "Matrix server URL" : "URL del servidor de Matrix",
    "User" : "Usuario",
    "Matrix channel" : "Canal de Matrix",
    "Mattermost server URL" : "URL del servidor de Mattermost",
    "Mattermost user" : "Usuario de Mattermost",
    "Team name" : "Nombre del equipo",
    "Channel name" : "Nombre del canal",
    "Rocket.Chat server URL" : "URL del servidor de RocketChat",
    "User name or email address" : "Nombre de usuario o dirección de email",
    "Rocket.Chat channel" : "Canal de Rocket.Chat",
    "Zulip server URL" : "URL del servidor Zulip",
    "Bot user name" : "Nombre de usuario del bot",
    "Bot API key" : "Clave de API del bot",
    "Zulip channel" : "Canal de Zulip",
    "API token" : "Token de API",
    "Slack channel" : "Canal de Slack",
    "Server ID or name" : "Nombre o ID del servidor",
    "Channel ID (prefixed with \"ID:\") or name" : "ID del canal (con el prefijo \"ID:\") o nombre",
    "Channel" : "Canal",
    "Login" : "Iniciar sesión",
    "Chat ID" : "ID del chat",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL del servidor IRC (p. ej., chat.freenode.net:6667)",
    "Nickname" : "Alias",
    "Connection password" : "Contraseña de la conexión",
    "IRC channel" : "Canal IRC",
    "Channel password" : "Contraseña del canal",
    "NickServ nickname" : "Alias de NickServ",
    "NickServ password" : "Contraseña de NickServ",
    "Use TLS" : "Usar TLS",
    "Use SASL" : "Usar SASL",
    "Tenant ID" : "ID de inquilino",
    "Client ID" : "ID de cliente",
    "Team ID" : "ID del equipo",
    "Thread ID" : "ID del hilo",
    "XMPP/Jabber server URL" : "URL del servidor XMPP/Jabber",
    "MUC server URL" : "URL del servidor MUC",
    "Jabber ID" : "ID de Jabber",
    "Media" : "Medios",
    "Polls" : "Encuestas",
    "Deck cards" : "Tarjetas Deck",
    "Voice messages" : "Mensajes de voz",
    "Locations" : "Ubicaciones",
    "Call recordings" : "Llamadas grabadas",
    "Audio" : "Audio",
    "Show all media" : "Mostrar todos los medios",
    "Show all files" : "Mostrar todos los archivos",
    "Show all polls" : "Mostrar todas las encuestas",
    "Show all deck cards" : "Mostrar todas las tarjetas deck",
    "Show all voice messages" : "Mostrar todos los mensajes de voz",
    "Show all locations" : "Mostrar todas las ubicaciones",
    "Show all call recordings" : "Mostrar todas las llamadas grabadas",
    "Show all audio" : "Mostrar todo el audio",
    "Show all other" : "Mostrar todo lo demás",
    "Follow conversation settings" : "Seguir los ajustes de la conversación",
    "Group" : "Grupo",
    "Team" : "Equipo",
    "You reconnected to the call" : "Ud. re-conectó la llamada",
    "{actor} reconnected to the call" : "{actor} se ha re-conectado a la llamada",
    "You added {user0} and {user1}" : "Añadió a {user0} y {user1}",
    "_You added {user0}, {user1} and %n more participant_::_You added {user0}, {user1} and %n more participants_" : ["Añadió a {user0}, {user1} y a %n participante más","Añadió a {user0}, {user1} y a %n participantes más","Añadió a {user0}, {user1} y a %n participantes más"],
    "An administrator added you and {user0}" : "Un administrador lo ha añadido a Ud. y a {user0}",
    "{actor} added you and {user0}" : "{actor} lo ha añadido a Ud. y a {user0}",
    "_An administrator added you, {user0} and %n more participant_::_An administrator added you, {user0} and %n more participants_" : ["Un administrador lo ha añadido a Ud., {user0} y a %n participante más","Un administrador lo ha añadido a Ud., {user0} y a %n participantes más","Un administrador lo ha añadido a Ud., {user0} y a %n participantes más"],
    "_{actor} added you, {user0} and %n more participant_::_{actor} added you, {user0} and %n more participants_" : ["{actor} lo ha añadido a Ud., {user0} y a %n participante más","{actor} lo ha añadido a Ud., {user0} y a %n participantes más","{actor} lo ha añadido a Ud., {user0} y a %n participantes más"],
    "An administrator added {user0} and {user1}" : "Un administrador añadió a {user0} y a {user1}",
    "{actor} added {user0} and {user1}" : "{actor} añadió a {user0} y a {user1}",
    "_An administrator added {user0}, {user1} and %n more participant_::_An administrator added {user0}, {user1} and %n more participants_" : ["Un administrador ha añadido a {user0}, {user1} y a %n participante más","Un administrador ha añadido a {user0}, {user1} y a %n participantes más","Un administrador ha añadido a {user0}, {user1} y a %n participantes más"],
    "_{actor} added {user0}, {user1} and %n more participant_::_{actor} added {user0}, {user1} and %n more participants_" : ["{actor} ha añadido a {user0}, {user1} y a %n participante más","{actor} ha añadido a {user0}, {user1} y a %n participantes más","{actor} ha añadido a {user0}, {user1} y a %n participantes más"],
    "You removed {user0} and {user1}" : "Ud. eliminó a {user0} y {user1}",
    "_You removed {user0}, {user1} and %n more participant_::_You removed {user0}, {user1} and %n more participants_" : ["Ud. eliminó a {user0} y {user1} y a %n participante más","Ud. eliminó a {user0} y {user1} y a %n participantes más","Ud. eliminó a {user0} y {user1} y a %n participantes más"],
    "An administrator removed you and {user0}" : "Un administrador lo eliminó a Ud. y a {user0}",
    "{actor} removed you and {user0}" : "{actor} lo eliminó a Ud. y a {user0}",
    "_An administrator removed you, {user0} and %n more participant_::_An administrator removed you, {user0} and %n more participants_" : ["Un administrador lo ha eliminado a Ud., a {user0} y a %n participante más","Un administrador lo ha eliminado a Ud., a {user0} y a %n participantes más","Un administrador lo ha eliminado a Ud., a {user0} y a %n participantes más"],
    "_{actor} removed you, {user0} and %n more participant_::_{actor} removed you, {user0} and %n more participants_" : ["{actor} lo ha eliminado a Ud., a {user0} y a %n participante más","{actor} lo ha eliminado a Ud., a {user0} y a %n participantes más","{actor} lo ha eliminado a Ud., a {user0} y a %n participantes más"],
    "An administrator removed {user0} and {user1}" : "Un administrador eliminó a {user0} y a {user1}",
    "{actor} removed {user0} and {user1}" : "{actor0} eliminó a {user0} y a {user1}",
    "_An administrator removed {user0}, {user1} and %n more participant_::_An administrator removed {user0}, {user1} and %n more participants_" : ["Un administrador ha eliminado a {user0}, {user1} y a %n participante más","Un administrador ha eliminado a {user0}, {user1} y a %n participantes más","Un administrador ha eliminado a {user0}, {user1} y a %n participantes más"],
    "_{actor} removed {user0}, {user1} and %n more participant_::_{actor} removed {user0}, {user1} and %n more participants_" : ["{actor} eliminó a {user0}, {user1} y a %n participante más","{actor} eliminó a {user0}, {user1} y a %n participantes más","{actor} eliminó a {user0}, {user1} y a %n participantes más"],
    "You and {user0} joined the call" : "Ud. y {user0} se unieron a la llamada",
    "_You, {user0} and %n more participant joined the call_::_You, {user0} and %n more participants joined the call_" : ["Ud., {user0} y %n participante más se ha unido a la llamada","Ud., {user0} y %n participantes más se han unido a la llamada","Ud., {user0} y %n participantes más se han unido a la llamada"],
    "{user0} and {user1} joined the call" : "{user0} y {user1} se unieron a la llamada",
    "_{user0}, {user1} and %n more participant joined the call_::_{user0}, {user1} and %n more participants joined the call_" : ["{user0}, {user1} y %n participante más se unieron a la llamada","{user0}, {user1} y %n participantes más se unieron a la llamada","{user0}, {user1} y %n participantes más se unieron a la llamada"],
    "You and {user0} left the call" : "Ud. y {user0} abandonaron la llamada",
    "_You, {user0} and %n more participant left the call_::_You, {user0} and %n more participants left the call_" : ["Ud., {user0} y %n participante más abandonaron la llamada","Ud., {user0} y %n participantes más abandonaron la llamada","Ud., {user0} y %n participantes más abandonaron la llamada"],
    "{user0} and {user1} left the call" : "{user0} y {user1} abandonaron a la llamada",
    "_{user0}, {user1} and %n more participant left the call_::_{user0}, {user1} and %n more participants left the call_" : ["{user0}, {user1} y %n participante más abandonaron la llamada","{user0}, {user1} y %n participantes más abandonaron la llamada","{user0}, {user1} y %n participantes más abandonaron la llamada"],
    "You promoted {user0} and {user1} to moderators" : "Ud. ha ascendido a {user0} y a {user1} a moderadores",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Ud. ha ascendido a {user0}, {user1} y a %n participante más a moderadores","Ud. ha ascendido a {user0}, {user1} y a %n participantes más a moderadores","Ud. ha ascendido a {user0}, {user1} y a %n participantes más a moderadores"],
    "An administrator promoted you and {user0} to moderators" : "Un administrador lo ha ascendido a Ud. y a {user0} a moderadores",
    "{actor} promoted you and {user0} to moderators" : "{actor} lo ha ascendido a Ud. y a {user0} a moderadores",
    "_An administrator promoted you, {user0} and %n more participant to moderators_::_An administrator promoted you, {user0} and %n more participants to moderators_" : ["Un administrador lo ha ascendido a Ud., {user0} y a %n participante más a moderadores","Un administrador lo ha ascendido a Ud., {user0} y a %n participantes más a moderadores","Un administrador lo ha ascendido a Ud., {user0} y a %n participantes más a moderadores"],
    "_{actor} promoted you, {user0} and %n more participant to moderators_::_{actor} promoted you, {user0} and %n more participants to moderators_" : ["{actor} le ha ascendido a Ud., {user0} y a %n participante más a moderadores","{actor} le ha ascendido a Ud., {user0} y a %n participantes más a moderadores","{actor} le ha ascendido a Ud., {user0} y a %n participantes más a moderadores"],
    "An administrator promoted {user0} and {user1} to moderators" : "Un administrador ha ascendido a {user0} y a {user1} a moderadores",
    "{actor} promoted {user0} and {user1} to moderators" : "{actor} ha ascendido a {user0} y a {user1} a moderadores",
    "_An administrator promoted {user0}, {user1} and %n more participant to moderators_::_An administrator promoted {user0}, {user1} and %n more participants to moderators_" : ["Un administrador ha ascendido a {user0}, {user1} y a %n participante más a moderadores","Un administrador ha ascendido a {user0}, {user1} y a %n participantes más a moderadores","Un administrador ha ascendido a {user0}, {user1} y a %n participantes más a moderadores"],
    "_{actor} promoted {user0}, {user1} and %n more participant to moderators_::_{actor} promoted {user0}, {user1} and %n more participants to moderators_" : ["{actor} ha ascendido a {user0}, {user1} y a %n participante más a moderadores","{actor} ha ascendido a {user0}, {user1} y a %n participantes más a moderadores","{actor} ha ascendido a {user0}, {user1} y a %n participantes más a moderadores"],
    "You demoted {user0} and {user1} from moderators" : "Ud. degradó a {user0} y a {user1} de su estatus de moderadores",
    "_You demoted {user0}, {user1} and %n more participant from moderators_::_You demoted {user0}, {user1} and %n more participants from moderators_" : ["Ud. degradó a {user0}, {user1} y a %n participante de su estatus de moderadores","Ud. degradó a {user0}, {user1} y a %n participantes más de su estatus de moderadores","Ud. degradó a {user0}, {user1} y a %n participantes más de su estatus de moderadores"],
    "An administrator demoted you and {user0} from moderators" : "Un administrador lo ha degradado a Ud. y a {user0} de su estatus de moderadores",
    "{actor} demoted you and {user0} from moderators" : "{actor} lo ha degradado a Ud. y a {user0} de su estatus de moderadores",
    "_An administrator demoted you, {user0} and %n more participant from moderators_::_An administrator demoted you, {user0} and %n more participants from moderators_" : ["Un administrador lo ha degradado a Ud., {user0} y %n participante más de su estatus de moderadores","Un administrador lo ha degradado a Ud., {user0} y %n participantes más de su estatus de moderadores","Un administrador lo ha degradado a Ud., {user0} y %n participantes más de su estatus de moderadores"],
    "_{actor} demoted you, {user0} and %n more participant from moderators_::_{actor} demoted you, {user0} and %n more participants from moderators_" : ["{actor} lo ha degradado a Ud., {user0} y a %n participante de su estatus de moderadores","{actor} lo ha degradado a Ud., {user0} y a %n participantes más de su estatus de moderadores","{actor} lo ha degradado a Ud., {user0} y a %n participantes más de su estatus de moderadores"],
    "An administrator demoted {user0} and {user1} from moderators" : "Un administrador degradó a {user0} y a {user1} de su estatus de moderadores",
    "{actor} demoted {user0} and {user1} from moderators" : "{actor} degradó a {user0} y a {user1} de su estatus de moderadores",
    "_An administrator demoted {user0}, {user1} and %n more participant from moderators_::_An administrator demoted {user0}, {user1} and %n more participants from moderators_" : ["Un administrador degradó a {user0}, {user1} y a %n participante más de su estatus de moderadores","Un administrador degradó a {user0}, {user1} y a %n participantes más de su estatus de moderadores","Un administrador degradó a {user0}, {user1} y a %n participantes más de su estatus de moderadores"],
    "_{actor} demoted {user0}, {user1} and %n more participant from moderators_::_{actor} demoted {user0}, {user1} and %n more participants from moderators_" : ["{actor} ha degradado a {user0}, {user1} y a %n participante más de su estatus de moderadores","{actor} ha degradado a {user0}, {user1} y a %n participantes más de su estatus de moderadores","{actor} ha degradado a {user0}, {user1} y a %n participantes más de su estatus de moderadores"],
    "You:" : "Usted:",
    "You: {lastMessage}" : "Tú: {lastMessage}",
    "{actor}:" : "{actor}:",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "(edited by you)" : "(editado por ud.)",
    "(edited by a deleted user)" : "(fue editado por un usuario eliminado)",
    "(edited by {moderator})" : "(editado por {moderator})",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Estás intentando unirte a una conversación mientras tienes activa una sesión en otra ventana o dispositivo. Nextcloud Talk no admite esto en la actualidad. ¿Qué prefieres hacer?",
    "Leave this page" : "Abandonar esta página",
    "Join here" : "Unirte aquí",
    "Deck card has been posted to {conversation}" : "La tarjeta Deck del tablero ha sido publicada a {conversation}",
    "An error occurred while posting deck card to conversation" : "Se ha producido un error al publicar la tarjeta de Deck en la conversación",
    "Post to a conversation" : "Publicar en una conversación",
    "Post to conversation" : "Publicar en la conversación",
    "The recording failed. Please contact your administrator." : "La grabación falló. Por favor, contacte a su administrador.",
    "Location has been posted to {conversation}" : "La ubicación se ha publicado en {conversation}",
    "An error occurred while posting location to conversation" : "Se ha producido un error al publicar la ubicación en la conversación",
    "Share to a conversation" : "Compartir en una conversación",
    "Share to conversation" : "Compartir en la conversación",
    "In conversation" : "En la conversación",
    "Search in conversation: {conversation}" : "Buscar en la conversación: {conversation}",
    "Your requests are throttled at the moment due to brute force protection" : "Sus solicitudes están siendo limitadas debido a la protección contra ataques de fuerza bruta",
    "Error while clearing conversation history" : "Error al vaciar el historial de conversaciones",
    "Error occurred while allowing guests" : "Se ha producido un error al permitir invitados",
    "Error occurred while disallowing guests" : "Se ha producido un error al prohibir invitados",
    "Error occurred when restricting the conversation to moderator" : "Se ha producido un error al restringir la conversación a los moderadores",
    "Error occurred when opening the conversation to everyone" : "Se ha producido un error al abrir la conversación a todo el mundo",
    "Conversation password has been saved" : "Se ha guardado la contraseña de la conversación",
    "Conversation password has been removed" : "Se ha eliminado la contraseña de la conversación",
    "Error occurred while saving conversation password" : "Se ha producido un error al guardar la contraseña",
    "Call recording is starting." : "La grabación de la llamada está comenzando.",
    "Call recording stopped while starting." : "La grabación de la llamada se detuvo mientras comenzaba.",
    "Call recording stopped. You will be notified once the recording is available." : "Se detuvo la grabación de la llamada. Se le notificará cuando la grabación esté disponible.",
    "Conversation picture set" : "Se ha establecido la imagen de la conversación",
    "Conversation picture deleted" : "Se eliminó la imagen de la conversación",
    "Could not delete the conversation picture" : "No fue posible eliminar la imagen de la conversación",
    "Could not remove the automatic expiration" : "No se pudo borrar la expiración automática",
    "Could not post message: {errorMessage}" : "No se ha podido publicar el mensaje: {errorMessage}",
    "Participant is banned successfully" : "El participante fue bloqueado exitosamente",
    "Error while banning the participant" : "Error al bloquear al participante",
    "An error occurred while fetching the participants" : "Ha ocurrido un error al recuperar los participantes",
    "Could not send invitation to {actorId}" : "No se ha enviado la invitación a {actorId}.",
    "Invitations sent" : "Invitaciones enviadas",
    "Error occurred when sending invitations" : "Se ha producido un error al enviar las invitaciones",
    "Failed to join the conversation." : "Error al unirse a la conversación.",
    "An error occurred while creating breakout rooms" : "Ocurrió un error mientras se creaban las salas de grupos",
    "An error occurred while re-ordering the attendees" : "Ocurrió un error mientras se reordenaban los asistentes",
    "An error occurred while deleting breakout rooms" : "Ocurrió un error mientras se eliminaban las salas de grupos",
    "An error occurred while starting breakout rooms" : "Ocurrió un error mientras se iniciaban las salas de grupos",
    "An error occurred while stopping breakout rooms" : "Ocurrió un error mientras se detenían las salas de grupos",
    "An error occurred while sending a message to the breakout rooms" : "Ocurrió un error mientras se enviaba un mensaje a las salas de grupos",
    "An error occurred while requesting assistance" : "Ocurrió un error mientras se solicitaba asistencia",
    "An error occurred while resetting the request for assistance" : "Ocurrió un error mientras se restablecía la solicitud de asistencia",
    "An error occurred while joining breakout room" : "Ha ocurrido un error al unirse a la sala de grupos",
    "Failed to rename the thread" : "Fallo al renombrar el hilo",
    "Error fetching upcoming events" : "Error al obtener los próximos eventos",
    "Error fetching upcoming reminders" : "Error al obtener las próximas notificaciones",
    "An error occurred while accepting an invitation" : "Ocurrió un error mientras se aceptaba una invitación",
    "An error occurred while rejecting an invitation" : "Ocurrió un error mientras se rechazaba una invitación",
    "{guest} (guest)" : "{guest} (invitado)",
    "Poll draft has been saved" : "El borrador de la encuesta ha sido guardado",
    "An error occurred while saving the draft" : "Ha ocurrido un error al guardar el borrador",
    "An error occurred while submitting your vote" : "Ocurrió un error mientras se enviaba su voto",
    "An error occurred while ending the poll" : "Ocurrió un error mientras se finalizaba la encuesta",
    "An error occurred while deleting the poll draft" : "Ha ocurrido un error mientras se eliminaba el borrador de la encuesta",
    "Poll \"{name}\" was created by {user}. Click to vote" : "La encuesta \"{name}\" fue creada por {user}. Haga clic para votar",
    "Failed to add reaction" : "Fallo al añadir reacción",
    "Failed to remove reaction" : "Fallo al quitar la reacción",
    "Error while uploading file \"{fileName}\"" : "Error al subir el archivo \"{fileName}\".",
    "Not enough free space to upload file \"{fileName}\"" : "No hay espacio libre suficiente para subir el archivo \"{fileName}\"",
    "You are not allowed to share files" : "No estás autorizado a compartir archivos",
    "Error while sharing file" : "Error al compartir archivo",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Este navegador no es completamente compatible con Nextcloud Talk. Por favor, usa la última versión de Mozilla Firefox, Microsoft Edge, Google Chrome, Opera o Apple Safari.",
    "_In %n hour_::_In %n hours_" : ["En %n hora","En %n horas","En %n horas"],
    "_%n minute _::_%n minutes_" : ["%n minuto","%n minutos","%n minutos"],
    "In {hours} and {minutes}" : "En {hours} y {minutes}",
    "_In %n minute_::_In %n minutes_" : ["En %n minuto","En %n minutos","En %n minutos"],
    "Later today – {timeLocale}" : "Hoy, más tarde – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Mañana – {timeLocale}",
    "This weekend – {timeLocale}" : "Este fin de semana – {timeLocale}",
    "Next week – {timeLocale}" : "Próxima semana – {timeLocale}",
    "Message link copied to clipboard" : "Link del mensaje copiado al portapapeles.",
    "Conversation link copied to clipboard" : "Enlace de la conversación copiado al portapapeles.",
    "The link could not be copied" : "No se pudo copiar el enlace",
    "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
    "Sending signaling message has failed" : "El envío del mensaje de señalización falló",
    "Lost connection to signaling server. Trying to reconnect." : "Se ha perdido la conexión con el servidor de señalización. Intentando reconectar.",
    "Lost connection to signaling server." : "Se ha perdido la conexión al servidor de señalización.",
    "The configured signaling server needs to be updated to be compatible with this version of Talk. Please contact your administration." : "El servidor de señalización configurado debe ser actualizado para que sea compatible con esta versión de Talk. Por favor, contacte a su administrador.",
    "Please restart the app." : "Por favor, reinicie la aplicación.",
    "Please reload the page." : "Por favor, recargue la página.",
    "Please try to restart the app." : "Por favor, intente reiniciar la aplicación.",
    "Please try to reload the page." : "Por favor, intente recargar la página.",
    "Do not disturb" : "No molestar",
    "Away" : "Ausente",
    "Microphone {number}" : "Micrófono {number}",
    "Camera {number}" : "Cámara {number}",
    "Speaker {number}" : "Altavoz {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Parece que estabas hablando con el micrófono silenciado, por favor desactiva el modo silencio para que los demás te oigan.",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "No se ha podido establecer conexión con por lo menos un participante. En este caso, puede ser necesario un servidor TURN. Por favor, pregunte a su administrador para configurar uno, siguiendo {linkstart}esta documentación{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Esto está tomando más tiempo de lo esperado. ¿Se han permitido (o rechazado) los permisos multimedia? Si es así, reinicie su navegador por favor, ya que el audio y el vídeo están fallando.",
    "Access to microphone & camera is only possible with HTTPS" : "Acceso a micrófono y cámara solo es posible con HTTPS",
    "Please move your setup to HTTPS" : "Por favor, cambia tu configuración a HTTPS",
    "Access to microphone & camera was denied" : "Acceso a micrófono y cámara fue rechazado",
    "WebRTC is not supported in your browser" : "Tu navegador no es compatible con WebRTC.",
    "Please use a different browser like Firefox or Chrome" : "Por favor, usa un navegador diferente, como Firefox o Chrome.",
    "Error while accessing microphone & camera" : "Error al acceder al micrófono y la cámara.",
    "%s Talk on your mobile devices" : "%s Talk en tus dispositivos móviles",
    "Join conversations at any time, anywhere, on any device." : "Únase a conversaciones en cualquier momento, en cualquier lugar, en cualquier dispositivo.",
    "Android app" : "App Android",
    "iOS app" : "App iOS",
    "__language_name__" : "Español (España)",
    "Webhook Demo" : "Demostración de Webhooks",
    "Call summary (%s)" : "Resumen de la llamada (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "El bot de resumen de llamada publica un mensaje de visión general listando a todos los participantes y delineando tareas",
    "Tasks" : "Tareas",
    "Notes" : "Notas",
    "Reports" : "Informes",
    "Decisions" : "Decisiones",
    "Agenda" : "Agenda",
    "Call summary" : "Resumen de la llamada",
    "Call summary - {title}" : "Resumen de la llamada - {title}",
    "Talk conversation for event" : "Conversación de Talk para el evento",
    "Client Push is installed, this improves the performance of desktop clients." : "Client Push se encuentra instalado, esto mejorará el rendimiento de los clientes de escritorio.",
    "{notify_push} is not installed, this might lead to performance issues when using desktop clients." : "{notify_push}no se encuentra instalado, esto podría conllevar a problemas de rendimiento cuando se utilizan clientes de escritorio.",
    "Next meeting" : "Siguiente reunión",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Programe una reunión desde su calendario. Una conversación de Talk deberá ser puesta como ubicación para que sea mostrada aquí",
    "Join conversations from remote Nextcloud servers" : "Unirse a conversaciones de servidores Nextcloud remotos",
    "Your default media state has been saved" : "Se ha guardado el estado predeterminado de sus dispositivos",
    "Set reminder for later today" : "Establecer recordatorio para hoy, más tarde",
    "Set reminder for tomorrow" : "Establecer recordatorio para mañana",
    "Set reminder for this weekend" : "Establecer recordatorio para este fin de semana",
    "Set reminder for next week" : "Establecer recordatorio para la semana que viene",
    "Generate summary" : "Generar resumen",
    "Open poll • You voted already" : "Encuesta abierta ・ Ya ha votado",
    "Open poll • Click to vote" : "Encuesta abierta ・ Haga clic para votar",
    "Poll • Ended" : "Votación ・ Finalizada",
    "Talk recording from {time} ({conversation})" : "Grabación de la conversación desde {time} ({conversation})",
    "_Poll results • %n vote_::_Poll results • %n votes_" : ["Resultados de la encuesta • %n voto","Resultados de la encuesta • %n votos","Resultados de la encuesta • %n votos"],
    "_Open poll • %n vote_::_Open poll • %n votes_" : ["Encuesta abierta ・ %n voto","Encuesta abierta ・ %n votos","Encuesta abierta ・ %n votos"],
    "Submit vote" : "Enviar voto",
    "Your privacy setting has been saved" : "Se han guardado tus ajustes de privacidad",
    "Your personal setting has been saved" : "Sus ajustes personales se han guardado",
    "Failed to save sounds setting" : "Fallo al guardar la configuración de sonidos",
    "Sounds setting saved" : "Confuguración de sonidos guardada",
    "Nextcloud Talk was updated, you cannot start or join a call." : "Se ha actualizado Nextcloud Talk, no puede iniciar o unirse a una llamada.",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Te has unido a la conversación en otra ventana o dispositivo. Nextcloud Talk no soporta esto en la actualidad, por lo que se ha cerrado esta sesión.",
    "Nextcloud Talk was updated." : "Se ha actualizado Nextcloud Talk.",
    "Nextcloud is in maintenance mode." : "Nextcloud está en modo mantenimiento.",
    "Nextcloud Talk Federation was updated." : "Se ha actualizado la federación de Nextcloud Talk.",
    "Enable live translation" : "Activar traducción en vivo"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
